@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,6 +16,7 @@
 """This module contains support classes from which schema-specific bindings
 inherit, and that describe the content models of those schema."""
 
+import logging
 import pyxb
 import xml.dom
 import pyxb.utils.domutils as domutils
@@ -23,18 +25,7 @@ import types
 import pyxb.namespace
 from pyxb.namespace.builtin import XMLSchema_instance as XSI
 
-BINDING_STYLE_ACCESSOR = 'accessor'
-BINDING_STYLE_PROPERTY = 'property'
-
-BINDING_STYLES = (BINDING_STYLE_ACCESSOR, BINDING_STYLE_PROPERTY)
-DEFAULT_BINDING_STYLE = BINDING_STYLE_PROPERTY
-CURRENT_BINDING_STYLE = None
-
-def ConfigureBindingStyle (style):
-    global CURRENT_BINDING_STYLE
-    simpleTypeDefinition._ConfigureBindingStyle(style)
-    complexTypeDefinition._ConfigureBindingStyle(style)
-    CURRENT_BINDING_STYLE = style
+_log = logging.getLogger(__name__)
 
 class _TypeBinding_mixin (utility.Locatable_mixin):
 
@@ -53,6 +44,9 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
     _ExpandedName = None
     """The expanded name of the component."""
 
+    _DefinitionLocation = None
+    """Where the definition can be found in the originating schema."""
+
     _ReservedSymbols = set([ 'validateBinding', 'toDOM', 'toxml', 'Factory', 'property' ])
 
     if pyxb._CorruptionDetectionEnabled:
@@ -61,8 +55,6 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
                 raise pyxb.BindingError('Attempt to set reserved name %s in instance of %s' % (name, type(self)))
             return super(_TypeBinding_mixin, self).__setattr__(name, value)
 
-    # @todo: We don't actually use this anymore; get rid of it, just leaving a
-    # comment describing each keyword.
     _PyXBFactoryKeywords = ( '_dom_node', '_fallback_namespace', '_from_xml',
                              '_apply_whitespace_facet', '_validate_constraints',
                              '_require_value', '_nil', '_element',
@@ -263,7 +255,7 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
         required type.  Note that constraining facets are applied here if
         necessary (e.g., although a Python C{int} with value C{500} is
         type-compatible with C{xs:byte}, it is outside the value space, and
-        compatibility will fail.
+        compatibility will fail).
 
         @keyword _convert_string_values: If C{True} (default) and the incoming value is
         a string, an attempt will be made to form a compatible value by using
@@ -319,7 +311,7 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
             return value
         if pyxb.binding.datatypes.anyType == cls:
             if not isinstance(value, _TypeBinding_mixin):
-                print 'NOTE: Created %s instance from value of type %s' % (cls._ExpandedName, type(value))
+                _log.info('Created %s instance from value of type %s', cls._ExpandedName, type(value))
                 value = cls(value)
             return value
 
@@ -395,7 +387,7 @@ class _TypeBinding_mixin (utility.Locatable_mixin):
             if iv is not None:
                 attribute_settings[fu.name()] = iv
         for (attr_en, value) in attribute_settings.items():
-            au = self._setAttribute(attr_en, value)
+            self._setAttribute(attr_en, value)
 
     def toDOM (self, bds=None, parent=None, element_name=None):
         """Convert this instance to a DOM node.
@@ -568,8 +560,6 @@ class _DynamicCreate_mixin (pyxb.cscRoot):
         try:
             return ctor(*args, **kw)
         except TypeError, e:
-            #import traceback
-            #traceback.print_exc()
             raise pyxb.BadTypeValueError(e)
 
 class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
@@ -601,15 +591,6 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
     bindings."""
 
 
-    @classmethod
-    def _ConfigureBindingStyle (cls, style):
-        if BINDING_STYLE_PROPERTY == style:
-            pass
-        elif BINDING_STYLE_ACCESSOR == style:
-            pass
-        else:
-            raise pyxb.LogicError('Unrecognized binding style %s' % (style,))
-
     # Determine the name of the class-private facet map.  For the base class
     # this should produce the same attribute name as Python's privatization
     # scheme.
@@ -627,7 +608,7 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         ns_uri = ''
         try:
             ns_uri = cls._ExpandedName.namespaceURI()
-        except Exception, e:
+        except Exception:
             pass
         nm = '_' + utility.MakeIdentifier('%s_%s_FacetMap' % (ns_uri, cls.__name__.strip('_')))
         '''
@@ -645,7 +626,7 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
                 ns_uri = ''
                 try:
                     ns_uri = cls._ExpandedName.namespaceURI()
-                except Exception, e:
+                except Exception:
                     pass
                 nm = '_' + utility.MakeIdentifier('%s_%s_FacetMap' % (ns_uri, nm))
             cls.__FacetMapAttributeNameMap[cls] = nm
@@ -691,14 +672,12 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
             # Assume we're staying in this hierarchy.  Include source_class in
             # the candidates, since we might have jumped to it.
             for super_class in source_class.mro():
-                #print 'Superclass for %s is %s' % (source_class, super_class)
                 assert super_class is not None
                 if (super_class == simpleTypeDefinition): # and (source_class.XsdSuperType() is not None):
                     break
                 if issubclass(super_class, simpleTypeDefinition):
                     try:
                         fm = super_class._FacetMap()
-                        #print 'Selected facet map for %s from %s: %s' % (cls, super_class, fm)
                         break
                     except AttributeError:
                         pass
@@ -707,18 +686,13 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
                     source_class = source_class.XsdSuperType()
                 except AttributeError:
                     source_class = None
-                #print 'Nothing acceptable found, jumped to %s' % (source_class,)
                 if source_class is None:
                     fm = { }
-        #print 'Done with set'
         if fm is None:
             raise pyxb.LogicError('%s is not a child of simpleTypeDefinition' % (cls.__name__,))
         fm = fm.copy()
-        #print 'Augmenting %s map had %d elts with %d from args' % (cls, len(fm), len(args))
         for facet in args:
             fm[type(facet)] = facet
-        #for (fc, fi) in fm.items():
-        #    print ' %s : %s' % (fc, fi)
         setattr(cls, cls.__FacetMapAttributeName(), fm)
         return fm
 
@@ -747,7 +721,6 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         if (0 < len(args)) and isinstance(args[0], types.StringTypes) and apply_whitespace_facet:
             cf_whitespace = getattr(cls, '_CF_whiteSpace', None)
             if cf_whitespace is not None:
-                #print 'Apply whitespace %s to "%s"' % (cf_whitespace, args[0])
                 norm_str = unicode(cf_whitespace.normalizeString(args[0]))
                 args = (norm_str,) + args[1:]
         kw['_from_xml'] = from_xml
@@ -927,7 +900,7 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
                 # initialization should succceed.
                 try:
                     clazz_facets = clazz._FacetMap().values()
-                except AttributeError, e:
+                except AttributeError:
                     cache_result = False
                     clazz_facets = []
                 for v in clazz_facets:
@@ -938,7 +911,6 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         for f in facet_values:
             if not f.validateConstraint(value):
                 raise pyxb.BadTypeValueError('%s violation for %s in %s' % (f.Name(), value, cls.__name__))
-            #print '%s ok for %s' % (f, value)
         return value
 
     def xsdConstraintsOK (self):
@@ -1004,7 +976,7 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         try:
             self._CheckValidValue(value)
             return True
-        except pyxb.PyXBException, e:
+        except pyxb.PyXBException:
             pass
         return False
 
@@ -1018,20 +990,17 @@ class simpleTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixin
         append/extend on the list instance)."""
         if value is None:
             raise pyxb.BadTypeValueError('None is not a valid instance of %s' % (cls,))
-        #print 'testing value %s type %s against %s' % (value, type(value), cls)
         value_class = cls
         if issubclass(cls, STD_list):
-            #print ' -- checking list of %s' % (cls._ItemType,)
             try:
                 iter(value)
-            except TypeError, e:
+            except TypeError:
                 raise pyxb.BadTypeValueError('%s cannot have non-iterable value type %s' % (cls, type(value)))
             for v in value:
                 if not cls._ItemType._IsValidValue(v):
                     raise pyxb.BadTypeValueError('%s cannot have member of type %s (want %s)' % (cls, type(v), cls._ItemType))
         else:
             if issubclass(cls, STD_union):
-                #print ' -- checking union with %d types' % (len(cls._MemberTypes),)
                 value_class = None
                 for mt in cls._MemberTypes:
                     if mt._IsValidValue(value):
@@ -1107,7 +1076,7 @@ class STD_union (simpleTypeDefinition):
             arg = args[0]
             try:
                 rv = cls._ValidatedMember(arg)
-            except pyxb.BadTypeValueError, e:
+            except pyxb.BadTypeValueError:
                 pass
         if rv is None:
             kw['_validate_constraints'] = True
@@ -1248,7 +1217,7 @@ class STD_list (simpleTypeDefinition, types.ListType):
 
     def __setitem__ (self, key, value):
         if isinstance(key, slice):
-            super(STD_list, self).__setitem__(key, self.__convertMany(values))
+            super(STD_list, self).__setitem__(key, self.__convertMany(value))
         else:
             super(STD_list, self).__setitem__(key, self._ValidatedItem(value))
 
@@ -1390,6 +1359,7 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         self.__defaultValue = default_value
         self.__substitutionGroup = substitution_group
         self.__documentation = documentation
+        super(element, self).__init__()
         
     def __call__ (self, *args, **kw):
         """Invoke the Factory method on the type associated with this element.
@@ -1425,7 +1395,6 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         if value is None:
             return None
         is_plural = kw.pop('is_plural', False)
-        #print 'validating %s against %s, isPlural %s' % (type(value), self.typeDefinition(), is_plural)
         if is_plural:
             try:
                 iter(value)
@@ -1567,7 +1536,6 @@ class element (utility._DeconflictSymbols_mixin, _DynamicCreate_mixin):
         # Now determine the type binding for the content.  If xsi:type is
         # used, it won't be the one built into the element binding.
         type_class = element_binding.typeDefinition()
-        elt_ns = element_binding.name().namespace()
  
         # Get the namespace context for the value being created.  If none is
         # associated, one will be created.  Do not make assumptions about the
@@ -1693,15 +1661,6 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         """
         return self.__wildcardElements
 
-    @classmethod
-    def _ConfigureBindingStyle (cls, style):
-        if BINDING_STYLE_PROPERTY == style:
-            pass
-        elif BINDING_STYLE_ACCESSOR == style:
-            pass
-        else:
-            raise pyxb.LogicError('Unrecognized binding style %s' % (style,))
-
     def __init__ (self, *args, **kw):
         """Create a new instance of this binding.
 
@@ -1873,7 +1832,6 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
             value = eu.value(self)
             if value is None:
                 continue
-            res = None
             converter = eu.elementBinding().compatibleValue
             if eu.isPlural():
                 if 0 < len(value):
@@ -1906,7 +1864,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
             if isinstance(value, _TypeBinding_mixin):
                 value.validateBinding()
             elif eu is not None:
-                print 'WARNING: Cannot validate value %s in field %s' % (value, eu.id())
+                _log.warning('Cannot validate value %s in field %s', value, eu.id())
         self._validateAttributes()
         return True
 
@@ -2039,7 +1997,7 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
         # in saxer.
         element_binding = None
         if element_use is not None:
-            import content
+            from pyxb.binding import content
             assert isinstance(element_use, content.ElementUse)
             element_binding = element_use.elementBinding()
             assert element_binding is not None
@@ -2067,31 +2025,35 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                 else:
                     # Might be a resolvable wildcard.  See if we can convert it to an
                     # element.
-                    #print 'Attempting to create element from node %s' % (expanded_name,)
                     try:
                         ns = expanded_name.namespace()
                         if ns is not None:
                             for mr in ns.moduleRecords():
                                 try:
                                     if (mr.module() is None) and (mr.modulePath() is not None):
-                                        print 'Importing %s to get binding for wildcard %s' % (mr.modulePath(), expanded_name)
+                                        _log.info('Importing %s to get binding for wildcard %s', mr.modulePath(), expanded_name)
                                         mod = __import__(mr.modulePath())
                                         for c in mr.modulePath().split('.')[1:]:
                                             mod = getattr(mod, c)
                                         mr._setModule(mod)
-                                    value = mr.module().CreateFromDOM(node)
+                                    # The module holding XMLSchema bindings
+                                    # does not have a CreateFromDOM method,
+                                    # and shouldn't since we need to convert
+                                    # schema instances to DOM more carefully.
+                                    # Other namespaces won't have a module if
+                                    # the bindings were not imported; this is
+                                    # probably worth a warning.
+                                    if mr.module() is not None:
+                                        value = mr.module().CreateFromDOM(node)
+                                    elif mr.namespace() != pyxb.namespace.XMLSchema:
+                                        _log.warning('No bindings available for %s', expanded_name)
                                     break
+                                except pyxb.UnrecognizedElementError, e:
+                                    _log.info('Ignoring unrecognized element when creating binding for wildcard %s', expanded_name)
                                 except pyxb.PyXBException, e:
-                                    print 'Ignoring error when creating binding for wildcard %s: %s' % (expanded_name, e)
-                                except AttributeError, e:
-                                    # The module holding XMLSchema bindnigs does not
-                                    # have a CreateFromDOM method, and shouldn't since
-                                    # we need to convert schema instances to DOM more
-                                    # carefully.
-                                    if mr.namespace() != pyxb.namespace.XMLSchema:
-                                        raise
-                    except Exception, e:
-                        print 'WARNING: Unable to convert DOM node %s to Python instance: %s' % (expanded_name, e)
+                                    _log.warning('Ignoring error when creating binding for wildcard %s', expanded_name, exc_info=e)
+                    except Exception:
+                        _log.exception('Unable to convert DOM node %s to Python instance', expanded_name)
         if (not maybe_element) and isinstance(value, basestring) and (self._ContentTypeTag in (self._CT_EMPTY, self._CT_ELEMENT_ONLY)):
             if (0 == len(value.strip())) and not self._isNil():
                 return self
@@ -2108,7 +2070,6 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                     return self
                 raise pyxb.StructuralBadDocumentError('Validation is required when no element_use can be found')
             else:
-                #print 'SSStep %s %s' % (value, element_use)
                 ( consumed, underflow_exc ) = self.__modelState.step(self, value, element_use)
                 if consumed:
                     return self
@@ -2255,8 +2216,6 @@ class complexTypeDefinition (_TypeBinding_mixin, utility._DeconflictSymbols_mixi
                 desc.append("\n  Wildcard element(s)")
         return ''.join(desc)
 
-ConfigureBindingStyle(DEFAULT_BINDING_STYLE)
-
 ## Local Variables:
 ## fill-column:78
 ## End:
