@@ -1,4 +1,5 @@
-# Copyright 2009-2011, Peter A. Bigot
+# -*- coding: utf-8 -*-
+# Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain a
@@ -21,16 +22,17 @@ the Python field in which the values are stored.  They also provide the
 low-level interface to set and get the corresponding values in a binding
 instance.
 
-
-
 L{Wildcard} holds content-related information used in the content model.
 """
 
 import pyxb
 import pyxb.namespace
-import basis
+from pyxb.binding import basis
 
 import xml.dom
+import logging
+
+_log = logging.getLogger(__name__)
 
 class ContentState_mixin (pyxb.cscRoot):
     """Declares methods used by classes that hold state while validating a
@@ -48,7 +50,7 @@ class ContentState_mixin (pyxb.cscRoot):
         the proposed value completes the content model.
 
         @param instance: An instance of a subclass of
-        {basis.complexTypeDefinition}, into which the provided value will be
+        L{basis.complexTypeDefinition}, into which the provided value will be
         stored if it is consistent with the current model state.
 
         @param value: The value that is being validated against the state.
@@ -266,6 +268,7 @@ class AttributeUse (pyxb.cscRoot):
         self.__fixed = fixed
         self.__required = required
         self.__prohibited = prohibited
+        super(AttributeUse, self).__init__()
 
     def name (self):
         """The expanded name of the element.
@@ -527,6 +530,7 @@ class ElementUse (ContentState_mixin, ContentModel_mixin):
         self.__key = key
         self.__isPlural = is_plural
         self.__elementBinding = element_binding
+        super(ElementUse, self).__init__()
 
     def defaultValue (self):
         """Return the default value for this element.
@@ -659,15 +663,13 @@ class ElementUse (ContentState_mixin, ContentModel_mixin):
         try:
             self.setOrAppend(instance, self.__elementBinding.compatibleValue(value, _convert_string_values=False))
             return True
-        except pyxb.BadTypeValueError, e:
+        except pyxb.BadTypeValueError:
             pass
-        #print '%s %s %s in %s' % (instance, value, element_use, self)
         return False
 
     # CM._validate:ElementUse
     def _validate (self, symbol_set, output_sequence):
         values = symbol_set.get(self)
-        #print 'values %s' % (values,)
         if values is None:
             return False
         used = values.pop(0)
@@ -739,6 +741,7 @@ class Wildcard (ContentState_mixin, ContentModel_mixin):
             nsc = set([ self.__normalizeNamespace(_uri) for _uri in nsc ])
         self.__namespaceConstraint = nsc
         self.__processContents = kw['process_contents']
+        super(Wildcard, self).__init__()
 
     def matches (self, instance, value):
         """Return True iff the value is a valid match against this wildcard.
@@ -787,7 +790,7 @@ class Wildcard (ContentState_mixin, ContentModel_mixin):
         if not self.matches(instance, value):
             return False
         if not isinstance(value, basis._TypeBinding_mixin):
-            print 'NOTE: Created unbound wildcard element from %s' % (value_desc,)
+            _log.info('Created unbound wildcard element from %s', value_desc,)
         assert isinstance(instance.wildcardElements(), list), 'Uninitialized wildcard list in %s' % (instance._ExpandedName,)
         instance._appendWildcardElement(value)
         particle_state.incrementCount()
@@ -796,7 +799,7 @@ class Wildcard (ContentState_mixin, ContentModel_mixin):
     # CM._validate:Wildcard
     def _validate (self, symbol_set, output_sequence):
         # @todo check node against namespace constraint and process contents
-        #print 'WARNING: Accepting node as wildcard match without validating.'
+        _log.info('Accepting node as wildcard match without validating.')
         wc_values = symbol_set.get(None)
         if wc_values is None:
             return False
@@ -839,14 +842,12 @@ class SequenceState (ContentState_mixin):
         self.__failed = False
         # Kick this into the first element of the sequence
         self.notifyFailure(None, False)
-        #print 'SS.CTOR %s: %d elts' % (self, len(self.__particles))
 
     # CS.accepts:SequenceState
     def accepts (self, particle_state, instance, value, element_use):
         ## Implement ContentState_mixin.accepts
         assert self.__parentParticleState == particle_state
         assert not self.__failed
-        #print 'SS.ACC %s: %s %s %s' % (self, instance, value, element_use)
         while self.__particleState is not None:
             (consume, underflow_exc) = self.__particleState.step(instance, value, element_use)
             if consume:
@@ -871,7 +872,6 @@ class SequenceState (ContentState_mixin):
             self.__satisfied = particle_ok
             if particle_ok:
                 self.__parentParticleState.incrementCount()
-        #print 'SS.NF %s: %d %s %s' % (self, self.__index, particle_ok, self.__particleState)
 
 class ChoiceState (ContentState_mixin):
     def __init__ (self, group, parent_particle_state):
@@ -879,28 +879,23 @@ class ChoiceState (ContentState_mixin):
         super(ChoiceState, self).__init__(group)
         self.__choices = [ ParticleState(_p, self) for _p in group.particles() ]
         self.__activeChoice = None
-        #print 'CS.CTOR %s: %d choices' % (self, len(self.__choices))
 
     # CS.accepts:ChoiceState
     def accepts (self, particle_state, instance, value, element_use):
         ## Implement ContentState_mixin.accepts
-        #print 'CS.ACC %s %s: %s %s %s' % (self, self.__activeChoice, instance, value, element_use)
         if self.__activeChoice is None:
             for choice in self.__choices:
-                #print 'CS.ACC %s candidate %s' % (self, choice)
                 try:
                     (consume, underflow_exc) = choice.step(instance, value, element_use)
                 except Exception, e:
                     consume = False
                     underflow_exc = e
-                #print 'CS.ACC %s: candidate %s : %s' % (self, choice, consume)
                 if consume:
                     self.__activeChoice = choice
                     self.__choices = None
                     return True
             return False
         (consume, underflow_exc) = self.__activeChoice.step(instance, value, element_use)
-        #print 'CS.ACC %s : active choice %s %s %s' % (self, self.__activeChoice, consume, underflow_exc)
         if consume:
             return True
         if underflow_exc is not None:
@@ -910,25 +905,20 @@ class ChoiceState (ContentState_mixin):
 
     # CS._verifyComplete:ChoiceState
     def _verifyComplete (self, parent_particle_state):
-        rv = True
-        #print 'CS.VC %s: %s' % (self, self.__activeChoice)
         if self.__activeChoice is None:
             # Use self.__activeChoice as the iteration value so that it's
             # non-None when notifyFailure is invoked.
             for self.__activeChoice in self.__choices:
                 try:
-                    #print 'CS.VC: try %s' % (self.__activeChoice,)
                     self.__activeChoice.verifyComplete()
                     return
-                except Exception, e:
+                except Exception:
                     pass
-            #print 'Missing components %s' % ("\n".join([ "\n  ".join([str(_p2.term()) for _p2 in _p.particle().term().particles()]) for _p in self.__choices ]),)
             raise pyxb.MissingContentError('choice')
         self.__activeChoice.verifyComplete()
 
     # CS.notifyFailure:ChoiceState
     def notifyFailure (self, sub_state, particle_ok):
-        #print 'CS.NF %s %s' % (self, particle_ok)
         if particle_ok and (self.__activeChoice is not None):
             self.__parentParticleState.incrementCount()
         pass
@@ -940,30 +930,25 @@ class AllState (ContentState_mixin):
         self.__parentParticleState = parent_particle_state
         super(AllState, self).__init__(group)
         self.__choices = set([ ParticleState(_p, self) for _p in group.particles() ])
-        #print 'AS.CTOR %s: %d choices' % (self, len(self.__choices))
 
     # CS.accepts:AllState
     def accepts (self, particle_state, instance, value, element_use):
-        #print 'AS.ACC %s %s: %s %s %s' % (self, self.__activeChoice, instance, value, element_use)
         self.__needRetry = True
         while self.__needRetry:
             self.__needRetry = False
             if self.__activeChoice is None:
                 for choice in self.__choices:
-                    #print 'AS.ACC %s candidate %s' % (self, choice)
                     try:
                         (consume, underflow_exc) = choice.step(instance, value, element_use)
                     except Exception, e:
                         consume = False
                         underflow_exc = e
-                    #print 'AS.ACC %s: candidate %s : %s' % (self, choice, consume)
                     if consume:
                         self.__activeChoice = choice
                         self.__choices.discard(self.__activeChoice)
                         return True
                 return False
             (consume, underflow_exc) = self.__activeChoice.step(instance, value, element_use)
-            #print 'AS.ACC %s : active choice %s %s %s' % (self, self.__activeChoice, consume, underflow_exc)
             if consume:
                 return True
         if underflow_exc is not None:
@@ -973,7 +958,6 @@ class AllState (ContentState_mixin):
 
     # CS._verifyComplete:AllState
     def _verifyComplete (self, parent_particle_state):
-        #print 'AS.VC %s: %s, %d left' % (self, self.__activeChoice, len(self.__choices))
         if self.__activeChoice is not None:
             self.__activeChoice.verifyComplete()
         while self.__choices:
@@ -982,7 +966,6 @@ class AllState (ContentState_mixin):
 
     # CS.notifyFailure:AllState
     def notifyFailure (self, sub_state, particle_ok):
-        #print 'AS.NF %s %s' % (self, particle_ok)
         self.__needRetry = True
         self.__activeChoice = None
         if particle_ok and (0 == len(self.__choices)):
@@ -1004,7 +987,7 @@ class ParticleState (pyxb.cscRoot):
         self.__particle = particle
         self.__parentState = parent_state
         self.__count = -1
-        #print 'PS.CTOR %s: particle %s' % (self, particle)
+        super(ParticleState, self).__init__()
         self.incrementCount()
 
     __particle = None
@@ -1019,7 +1002,6 @@ class ParticleState (pyxb.cscRoot):
 
     def incrementCount (self):
         """Reset for a new occurrence of the particle's term."""
-        #print 'PS.IC %s' % (self,)
         self.__count += 1
         self.__termState = self.__particle.term().newState(self)
         self.__tryAccept = True
@@ -1031,7 +1013,6 @@ class ParticleState (pyxb.cscRoot):
 
         # @TODO@ Set a flag so we can make verifyComplete safe to call
         # multiple times?
-        #print 'PS.VC %s entry' % (self,)
 
         # If we're not satisfied, check the term: that might do it.
         if not self.__particle.satisfiesOccurrences(self.__count):
@@ -1039,7 +1020,6 @@ class ParticleState (pyxb.cscRoot):
 
         # If we're still not satisfied, raise an error
         if not self.__particle.satisfiesOccurrences(self.__count):
-            #print 'PS.VC %s incomplete' % (self,)
             raise pyxb.MissingContentError('incomplete')
 
         # If we are satisfied, tell the parent
@@ -1055,7 +1035,7 @@ class ParticleState (pyxb.cscRoot):
         particle has a parent state, it is informed of the failure.
 
         @param instance: An instance of a subclass of
-        {basis.complexTypeDefinition}, into which the provided value will be
+        L{basis.complexTypeDefinition}, into which the provided value will be
         stored if it is consistent with the current model state.
 
         @param value: The value that is being validated against the state.
@@ -1079,8 +1059,6 @@ class ParticleState (pyxb.cscRoot):
         term.
         """
 
-        #print 'PS.STEP %s: %s %s %s' % (self, instance, value, element_use)
-
         # Only try if we're not already at the upper limit on occurrences
         consumed = False
         underflow_exc = None
@@ -1092,9 +1070,7 @@ class ParticleState (pyxb.cscRoot):
         while self.__tryAccept and (self.__count != self.__particle.maxOccurs()):
             self.__tryAccept = False
             consumed = self.__termState.accepts(self, instance, value, element_use)
-            #print 'PS.STEP %s: ta %s %s' % (self, self.__tryAccept, consumed)
             self.__tryAccept = self.__tryAccept and (not consumed)
-        #print 'PS.STEP %s: %s' % (self, consumed)
         if consumed:
             if not self.__particle.meetsMaximum(self.__count):
                 raise pyxb.UnexpectedElementError('too many')
@@ -1154,6 +1130,7 @@ class ParticleModel (ContentModel_mixin):
         self.__term = term
         self.__minOccurs = min_occurs
         self.__maxOccurs = max_occurs
+        super(ParticleModel, self).__init__()
 
     # CM.newState:ParticleModel
     def newState (self):
@@ -1184,9 +1161,7 @@ class ParticleModel (ContentModel_mixin):
         """
         
         output_sequence = []
-        #print 'Start: %d %s %s : %s' % (self.__minOccurs, self.__maxOccurs, self.__term, symbol_set)
         result = self._validate(symbol_set, output_sequence)
-        #print 'End: %s %s %s' % (result, symbol_set, output_sequence)
         if result:
             return (symbol_set, output_sequence)
         return None
@@ -1196,10 +1171,8 @@ class ParticleModel (ContentModel_mixin):
         symbol_set_mut = self._validateCloneSymbolSet(symbol_set)
         output_sequence_mut = self._validateCloneOutputSequence(output_sequence)
         count = 0
-        #print 'VAL start %s: %d %s' % (self.__term, self.__minOccurs, self.__maxOccurs)
         last_size = len(output_sequence_mut)
         while (count != self.__maxOccurs) and self.__term._validate(symbol_set_mut, output_sequence_mut):
-            #print 'VAL %s old cnt %d, left %s' % (self.__term, count, symbol_set_mut)
             this_size = len(output_sequence_mut)
             if this_size == last_size:
                 # Validated without consuming anything.  Assume we can
@@ -1212,7 +1185,6 @@ class ParticleModel (ContentModel_mixin):
         result = self.satisfiesOccurrences(count)
         if (result):
             self._validateReplaceResults(symbol_set, symbol_set_mut, output_sequence, output_sequence_mut)
-        #print 'VAL end PRT %s res %s: %s %s %s' % (self.__term, result, self.__minOccurs, count, self.__maxOccurs)
         return result
 
 class _Group (ContentModel_mixin):
@@ -1235,6 +1207,7 @@ class _Group (ContentModel_mixin):
 
     def __init__ (self, *particles):
         self.__particles = particles
+        super(_Group, self).__init__()
 
     # CM.newState:_Group
     # CM.newState:GroupAll CM.newState:GroupSequence CM.newState:GroupChoice
