@@ -1,4 +1,5 @@
-# Copyright 2009, Peter A. Bigot
+# -*- coding: utf-8 -*-
+# Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain a
@@ -22,14 +23,15 @@ value spaces.
 
 """
 
-from xml.dom import Node
 import pyxb
 import types
 import datatypes
 import basis
 from pyxb.utils import utility
-from pyxb.utils import domutils
 import re
+import logging
+
+_log = logging.getLogger(__name__)
 
 class Facet (pyxb.cscRoot):
     """The base class for facets.
@@ -149,8 +151,8 @@ class Facet (pyxb.cscRoot):
         if (self.valueDatatype() is not None) and (self.value() is not None):
             try:
                 return self.valueDatatype().XsdLiteral(self.value())
-            except Exception, e:
-                print 'Stringize facet %s produced %s' % (self.Name(), e)
+            except Exception:
+                _log.exception('Stringize facet %s produced exception', self.Name())
                 raise
         return str(self.value())
     
@@ -301,7 +303,6 @@ class _CollectionFacet_mixin (pyxb.cscRoot):
         if kw.get('_reset', False):
             self.__items = []
         if not kw.get('_constructor', False):
-            #print self._CollectionFacet_itemType
             self.__items.append(self._CollectionFacet_itemType(facet_instance=self, **kw))
         super_fn = getattr(super(_CollectionFacet_mixin, self), '_setFromKeywords_vb', lambda *a,**kw: self)
         return super_fn(**kw)
@@ -383,8 +384,7 @@ class _PatternElement (utility.PrivateTransient_mixin):
         self.pattern = pattern
         self.annotation = annotation
         self.__pythonExpression = pyxb.utils.xmlre.XMLToPython(pattern)
-        #print 'Translated pattern %s to %s' % (pattern.encode('ascii', 'xmlcharrefreplace'),
-        #                                       self.__pythonExpression.encode('ascii', 'xmlcharrefreplace'))
+        super(_PatternElement, self).__init__()
 
     def __str__ (self): return self.pattern
 
@@ -756,7 +756,7 @@ class FundamentalFacet (Facet):
     def _updateFromDOM (self, node):
         try:
             super(FundamentalFacet, self)._updateFromDOM(node)
-        except AttributeError, e:
+        except AttributeError:
             pass
         if (self.valueDatatype() is not None) and node.hasAttribute('value'):
             self._value(self.valueDatatype()(node.getAttribute('value')))
