@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsa.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:0ecbd27a42302a2dbf33a51269e14ce6419c0738
-# Generated 2012-06-15 14:42:57.838239 by PyXB version 1.1.4
+# Generated 2012-11-01 15:13:37.230084 by PyXB version 1.1.5
 # Namespace http://www.w3.org/2005/08/addressing
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:4ee3d8ce-b722-11e1-96c7-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9eabb952-2460-11e2-a569-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -59,12 +59,44 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
-# Atomic SimpleTypeDefinition
+# Atomic simple type: {http://www.w3.org/2005/08/addressing}RelationshipType
+class RelationshipType (pyxb.binding.datatypes.anyURI, pyxb.binding.basis.enumeration_mixin):
+
+    """An atomic simple type."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'RelationshipType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 64, 1)
+    _Documentation = None
+RelationshipType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipType, enum_prefix=None)
+RelationshipType.httpwww_w3_org200508addressingreply = RelationshipType._CF_enumeration.addEnumeration(unicode_value=u'http://www.w3.org/2005/08/addressing/reply', tag=u'httpwww_w3_org200508addressingreply')
+RelationshipType._InitializeFacetMap(RelationshipType._CF_enumeration)
+Namespace.addCategoryObject('typeBinding', u'RelationshipType', RelationshipType)
+
+# Union simple type: {http://www.w3.org/2005/08/addressing}RelationshipTypeOpenEnum
+# superclasses pyxb.binding.datatypes.anySimpleType
+class RelationshipTypeOpenEnum (pyxb.binding.basis.STD_union):
+
+    """Simple type that is a union of RelationshipType, pyxb.binding.datatypes.anyURI."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'RelationshipTypeOpenEnum')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 60, 1)
+    _Documentation = None
+
+    _MemberTypes = ( RelationshipType, pyxb.binding.datatypes.anyURI, )
+RelationshipTypeOpenEnum._CF_pattern = pyxb.binding.facets.CF_pattern()
+RelationshipTypeOpenEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipTypeOpenEnum)
+RelationshipTypeOpenEnum.httpwww_w3_org200508addressingreply = u'http://www.w3.org/2005/08/addressing/reply'# originally RelationshipType.httpwww_w3_org200508addressingreply
+RelationshipTypeOpenEnum._InitializeFacetMap(RelationshipTypeOpenEnum._CF_pattern,
+   RelationshipTypeOpenEnum._CF_enumeration)
+Namespace.addCategoryObject('typeBinding', u'RelationshipTypeOpenEnum', RelationshipTypeOpenEnum)
+
+# Atomic simple type: {http://www.w3.org/2005/08/addressing}FaultCodesType
 class FaultCodesType (pyxb.binding.datatypes.QName, pyxb.binding.basis.enumeration_mixin):
 
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'FaultCodesType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 92, 1)
     _Documentation = None
 FaultCodesType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FaultCodesType, enum_prefix=None)
 FaultCodesType.tnsInvalidAddressingHeader = FaultCodesType._CF_enumeration.addEnumeration(unicode_value=u'tns:InvalidAddressingHeader', tag=u'tnsInvalidAddressingHeader')
@@ -81,18 +113,19 @@ FaultCodesType.tnsEndpointUnavailable = FaultCodesType._CF_enumeration.addEnumer
 FaultCodesType._InitializeFacetMap(FaultCodesType._CF_enumeration)
 Namespace.addCategoryObject('typeBinding', u'FaultCodesType', FaultCodesType)
 
-# Union SimpleTypeDefinition
+# Union simple type: {http://www.w3.org/2005/08/addressing}FaultCodesOpenEnumType
 # superclasses pyxb.binding.datatypes.anySimpleType
 class FaultCodesOpenEnumType (pyxb.binding.basis.STD_union):
 
     """Simple type that is a union of FaultCodesType, pyxb.binding.datatypes.QName."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'FaultCodesOpenEnumType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 88, 1)
     _Documentation = None
 
     _MemberTypes = ( FaultCodesType, pyxb.binding.datatypes.QName, )
-FaultCodesOpenEnumType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FaultCodesOpenEnumType)
 FaultCodesOpenEnumType._CF_pattern = pyxb.binding.facets.CF_pattern()
+FaultCodesOpenEnumType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FaultCodesOpenEnumType)
 FaultCodesOpenEnumType.tnsInvalidAddressingHeader = u'tns:InvalidAddressingHeader'# originally FaultCodesType.tnsInvalidAddressingHeader
 FaultCodesOpenEnumType.tnsInvalidAddress = u'tns:InvalidAddress'# originally FaultCodesType.tnsInvalidAddress
 FaultCodesOpenEnumType.tnsInvalidEPR = u'tns:InvalidEPR'# originally FaultCodesType.tnsInvalidEPR
@@ -104,45 +137,17 @@ FaultCodesOpenEnumType.tnsMessageAddressingHeaderRequired = u'tns:MessageAddress
 FaultCodesOpenEnumType.tnsDestinationUnreachable = u'tns:DestinationUnreachable'# originally FaultCodesType.tnsDestinationUnreachable
 FaultCodesOpenEnumType.tnsActionNotSupported = u'tns:ActionNotSupported'# originally FaultCodesType.tnsActionNotSupported
 FaultCodesOpenEnumType.tnsEndpointUnavailable = u'tns:EndpointUnavailable'# originally FaultCodesType.tnsEndpointUnavailable
-FaultCodesOpenEnumType._InitializeFacetMap(FaultCodesOpenEnumType._CF_enumeration,
-   FaultCodesOpenEnumType._CF_pattern)
+FaultCodesOpenEnumType._InitializeFacetMap(FaultCodesOpenEnumType._CF_pattern,
+   FaultCodesOpenEnumType._CF_enumeration)
 Namespace.addCategoryObject('typeBinding', u'FaultCodesOpenEnumType', FaultCodesOpenEnumType)
 
-# Atomic SimpleTypeDefinition
-class RelationshipType (pyxb.binding.datatypes.anyURI, pyxb.binding.basis.enumeration_mixin):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'RelationshipType')
-    _Documentation = None
-RelationshipType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipType, enum_prefix=None)
-RelationshipType.httpwww_w3_org200508addressingreply = RelationshipType._CF_enumeration.addEnumeration(unicode_value=u'http://www.w3.org/2005/08/addressing/reply', tag=u'httpwww_w3_org200508addressingreply')
-RelationshipType._InitializeFacetMap(RelationshipType._CF_enumeration)
-Namespace.addCategoryObject('typeBinding', u'RelationshipType', RelationshipType)
-
-# Union SimpleTypeDefinition
-# superclasses pyxb.binding.datatypes.anySimpleType
-class RelationshipTypeOpenEnum (pyxb.binding.basis.STD_union):
-
-    """Simple type that is a union of RelationshipType, pyxb.binding.datatypes.anyURI."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'RelationshipTypeOpenEnum')
-    _Documentation = None
-
-    _MemberTypes = ( RelationshipType, pyxb.binding.datatypes.anyURI, )
-RelationshipTypeOpenEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=RelationshipTypeOpenEnum)
-RelationshipTypeOpenEnum._CF_pattern = pyxb.binding.facets.CF_pattern()
-RelationshipTypeOpenEnum.httpwww_w3_org200508addressingreply = u'http://www.w3.org/2005/08/addressing/reply'# originally RelationshipType.httpwww_w3_org200508addressingreply
-RelationshipTypeOpenEnum._InitializeFacetMap(RelationshipTypeOpenEnum._CF_enumeration,
-   RelationshipTypeOpenEnum._CF_pattern)
-Namespace.addCategoryObject('typeBinding', u'RelationshipTypeOpenEnum', RelationshipTypeOpenEnum)
-
-# Complex type AttributedURIType with content type SIMPLE
+# Complex type {http://www.w3.org/2005/08/addressing}AttributedURIType with content type SIMPLE
 class AttributedURIType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = pyxb.binding.datatypes.anyURI
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedURIType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 76, 1)
     # Base type is pyxb.binding.datatypes.anyURI
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
 
@@ -155,16 +160,94 @@ class AttributedURIType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'AttributedURIType', AttributedURIType)
 
 
-# Complex type EndpointReferenceType with content type ELEMENT_ONLY
+# Complex type {http://www.w3.org/2005/08/addressing}RelatesToType with content type SIMPLE
+class RelatesToType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = pyxb.binding.datatypes.anyURI
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'RelatesToType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 51, 1)
+    # Base type is pyxb.binding.datatypes.anyURI
+    
+    # Attribute RelationshipType uses Python identifier RelationshipType
+    __RelationshipType = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'RelationshipType'), 'RelationshipType', '__httpwww_w3_org200508addressing_RelatesToType_RelationshipType', RelationshipTypeOpenEnum, unicode_default=u'http://www.w3.org/2005/08/addressing/reply')
+    __RelationshipType._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 54, 4)
+    __RelationshipType._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 54, 4)
+    
+    RelationshipType = property(__RelationshipType.value, __RelationshipType.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        __RelationshipType.name() : __RelationshipType
+    }
+Namespace.addCategoryObject('typeBinding', u'RelatesToType', RelatesToType)
+
+
+# Complex type {http://www.w3.org/2005/08/addressing}AttributedUnsignedLongType with content type SIMPLE
+class AttributedUnsignedLongType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = pyxb.binding.datatypes.unsignedLong
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedUnsignedLongType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 109, 1)
+    # Base type is pyxb.binding.datatypes.unsignedLong
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'AttributedUnsignedLongType', AttributedUnsignedLongType)
+
+
+# Complex type {http://www.w3.org/2005/08/addressing}MetadataType with content type ELEMENT_ONLY
+class MetadataType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'MetadataType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 42, 1)
+    # Base type is pyxb.binding.datatypes.anyType
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'MetadataType', MetadataType)
+
+
+# Complex type {http://www.w3.org/2005/08/addressing}EndpointReferenceType with content type ELEMENT_ONLY
 class EndpointReferenceType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'EndpointReferenceType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 23, 1)
     # Base type is pyxb.binding.datatypes.anyType
     
+    # Element {http://www.w3.org/2005/08/addressing}Metadata uses Python identifier Metadata
+    __Metadata = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), 'Metadata', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingMetadata', False)
+    __Metadata._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 41, 1)
+    __Metadata._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 24, 2)
+
+    
+    Metadata = property(__Metadata.value, __Metadata.set, None, None)
+
+    
     # Element {http://www.w3.org/2005/08/addressing}Address uses Python identifier Address
     __Address = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Address'), 'Address', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingAddress', False)
+    __Address._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 25, 3)
+    __Address._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 24, 2)
 
     
     Address = property(__Address.value, __Address.set, None, None)
@@ -172,24 +255,19 @@ class EndpointReferenceType (pyxb.binding.basis.complexTypeDefinition):
     
     # Element {http://www.w3.org/2005/08/addressing}ReferenceParameters uses Python identifier ReferenceParameters
     __ReferenceParameters = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), 'ReferenceParameters', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingReferenceParameters', False)
+    __ReferenceParameters._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 33, 1)
+    __ReferenceParameters._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 24, 2)
 
     
     ReferenceParameters = property(__ReferenceParameters.value, __ReferenceParameters.set, None, None)
 
-    
-    # Element {http://www.w3.org/2005/08/addressing}Metadata uses Python identifier Metadata
-    __Metadata = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), 'Metadata', '__httpwww_w3_org200508addressing_EndpointReferenceType_httpwww_w3_org200508addressingMetadata', False)
-
-    
-    Metadata = property(__Metadata.value, __Metadata.set, None, None)
-
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
     _HasWildcardElement = True
 
     _ElementMap = {
+        __Metadata.name() : __Metadata,
         __Address.name() : __Address,
-        __ReferenceParameters.name() : __ReferenceParameters,
-        __Metadata.name() : __Metadata
+        __ReferenceParameters.name() : __ReferenceParameters
     }
     _AttributeMap = {
         
@@ -197,16 +275,58 @@ class EndpointReferenceType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'EndpointReferenceType', EndpointReferenceType)
 
 
-# Complex type ProblemActionType with content type ELEMENT_ONLY
+# Complex type {http://www.w3.org/2005/08/addressing}AttributedQNameType with content type SIMPLE
+class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = pyxb.binding.datatypes.QName
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 118, 1)
+    # Base type is pyxb.binding.datatypes.QName
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
+
+
+# Complex type {http://www.w3.org/2005/08/addressing}ReferenceParametersType with content type ELEMENT_ONLY
+class ReferenceParametersType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ReferenceParametersType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 34, 1)
+    # Base type is pyxb.binding.datatypes.anyType
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'ReferenceParametersType', ReferenceParametersType)
+
+
+# Complex type {http://www.w3.org/2005/08/addressing}ProblemActionType with content type ELEMENT_ONLY
 class ProblemActionType (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ProblemActionType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 129, 1)
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://www.w3.org/2005/08/addressing}SoapAction uses Python identifier SoapAction
     __SoapAction = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'), 'SoapAction', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingSoapAction', False)
+    __SoapAction._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 132, 3)
+    __SoapAction._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 130, 2)
 
     
     SoapAction = property(__SoapAction.value, __SoapAction.set, None, None)
@@ -214,6 +334,8 @@ class ProblemActionType (pyxb.binding.basis.complexTypeDefinition):
     
     # Element {http://www.w3.org/2005/08/addressing}Action uses Python identifier Action
     __Action = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Action'), 'Action', '__httpwww_w3_org200508addressing_ProblemActionType_httpwww_w3_org200508addressingAction', False)
+    __Action._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 74, 1)
+    __Action._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wsa.xsd', 130, 2)
 
     
     Action = property(__Action.value, __Action.set, None, None)
@@ -230,133 +352,8 @@ class ProblemActionType (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'ProblemActionType', ProblemActionType)
 
 
-# Complex type ReferenceParametersType with content type ELEMENT_ONLY
-class ReferenceParametersType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ReferenceParametersType')
-    # Base type is pyxb.binding.datatypes.anyType
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'ReferenceParametersType', ReferenceParametersType)
-
-
-# Complex type MetadataType with content type ELEMENT_ONLY
-class MetadataType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'MetadataType')
-    # Base type is pyxb.binding.datatypes.anyType
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'MetadataType', MetadataType)
-
-
-# Complex type RelatesToType with content type SIMPLE
-class RelatesToType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.anyURI
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'RelatesToType')
-    # Base type is pyxb.binding.datatypes.anyURI
-    
-    # Attribute RelationshipType uses Python identifier RelationshipType
-    __RelationshipType = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'RelationshipType'), 'RelationshipType', '__httpwww_w3_org200508addressing_RelatesToType_RelationshipType', RelationshipTypeOpenEnum, unicode_default=u'http://www.w3.org/2005/08/addressing/reply')
-    
-    RelationshipType = property(__RelationshipType.value, __RelationshipType.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        __RelationshipType.name() : __RelationshipType
-    }
-Namespace.addCategoryObject('typeBinding', u'RelatesToType', RelatesToType)
-
-
-# Complex type AttributedUnsignedLongType with content type SIMPLE
-class AttributedUnsignedLongType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.unsignedLong
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedUnsignedLongType')
-    # Base type is pyxb.binding.datatypes.unsignedLong
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'AttributedUnsignedLongType', AttributedUnsignedLongType)
-
-
-# Complex type AttributedQNameType with content type SIMPLE
-class AttributedQNameType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = pyxb.binding.datatypes.QName
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'AttributedQNameType')
-    # Base type is pyxb.binding.datatypes.QName
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2005/08/addressing'))
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'AttributedQNameType', AttributedQNameType)
-
-
-FaultTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'FaultTo'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', FaultTo.name().localName(), FaultTo)
-
-EndpointReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'EndpointReference'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', EndpointReference.name().localName(), EndpointReference)
-
-From = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'From'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', From.name().localName(), From)
-
-To = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'To'), AttributedURIType)
-Namespace.addCategoryObject('elementBinding', To.name().localName(), To)
-
-ProblemAction = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemAction'), ProblemActionType)
-Namespace.addCategoryObject('elementBinding', ProblemAction.name().localName(), ProblemAction)
-
-Action = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Action'), AttributedURIType)
-Namespace.addCategoryObject('elementBinding', Action.name().localName(), Action)
-
-ReplyTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReplyTo'), EndpointReferenceType)
-Namespace.addCategoryObject('elementBinding', ReplyTo.name().localName(), ReplyTo)
-
-ReferenceParameters = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), ReferenceParametersType)
-Namespace.addCategoryObject('elementBinding', ReferenceParameters.name().localName(), ReferenceParameters)
-
-Metadata = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), MetadataType)
-Namespace.addCategoryObject('elementBinding', Metadata.name().localName(), Metadata)
-
-ProblemIRI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemIRI'), AttributedURIType)
-Namespace.addCategoryObject('elementBinding', ProblemIRI.name().localName(), ProblemIRI)
+MessageID = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'MessageID'), AttributedURIType)
+Namespace.addCategoryObject('elementBinding', MessageID.name().localName(), MessageID)
 
 RelatesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'RelatesTo'), RelatesToType)
 Namespace.addCategoryObject('elementBinding', RelatesTo.name().localName(), RelatesTo)
@@ -364,19 +361,52 @@ Namespace.addCategoryObject('elementBinding', RelatesTo.name().localName(), Rela
 RetryAfter = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'RetryAfter'), AttributedUnsignedLongType)
 Namespace.addCategoryObject('elementBinding', RetryAfter.name().localName(), RetryAfter)
 
-MessageID = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'MessageID'), AttributedURIType)
-Namespace.addCategoryObject('elementBinding', MessageID.name().localName(), MessageID)
+Metadata = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), MetadataType)
+Namespace.addCategoryObject('elementBinding', Metadata.name().localName(), Metadata)
+
+EndpointReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'EndpointReference'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', EndpointReference.name().localName(), EndpointReference)
+
+From = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'From'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', From.name().localName(), From)
 
 ProblemHeaderQName = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemHeaderQName'), AttributedQNameType)
 Namespace.addCategoryObject('elementBinding', ProblemHeaderQName.name().localName(), ProblemHeaderQName)
 
+Action = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Action'), AttributedURIType)
+Namespace.addCategoryObject('elementBinding', Action.name().localName(), Action)
 
+ReferenceParameters = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), ReferenceParametersType)
+Namespace.addCategoryObject('elementBinding', ReferenceParameters.name().localName(), ReferenceParameters)
+
+ProblemIRI = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemIRI'), AttributedURIType)
+Namespace.addCategoryObject('elementBinding', ProblemIRI.name().localName(), ProblemIRI)
+
+To = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'To'), AttributedURIType)
+Namespace.addCategoryObject('elementBinding', To.name().localName(), To)
+
+ProblemAction = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ProblemAction'), ProblemActionType)
+Namespace.addCategoryObject('elementBinding', ProblemAction.name().localName(), ProblemAction)
+
+FaultTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'FaultTo'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', FaultTo.name().localName(), FaultTo)
+
+ReplyTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReplyTo'), EndpointReferenceType)
+Namespace.addCategoryObject('elementBinding', ReplyTo.name().localName(), ReplyTo)
+
+
+MetadataType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+    )
+MetadataType._ContentModel = pyxb.binding.content.ParticleModel(MetadataType._GroupModel, min_occurs=1, max_occurs=1)
+
+
+
+EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), MetadataType, scope=EndpointReferenceType))
 
 EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Address'), AttributedURIType, scope=EndpointReferenceType))
 
 EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters'), ReferenceParametersType, scope=EndpointReferenceType))
-
-EndpointReferenceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Metadata'), MetadataType, scope=EndpointReferenceType))
 EndpointReferenceType._GroupModel = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Address')), min_occurs=1, max_occurs=1),
     pyxb.binding.content.ParticleModel(EndpointReferenceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ReferenceParameters')), min_occurs=0L, max_occurs=1),
@@ -386,6 +416,12 @@ EndpointReferenceType._GroupModel = pyxb.binding.content.GroupSequence(
 EndpointReferenceType._ContentModel = pyxb.binding.content.ParticleModel(EndpointReferenceType._GroupModel, min_occurs=1, max_occurs=1)
 
 
+ReferenceParametersType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+    )
+ReferenceParametersType._ContentModel = pyxb.binding.content.ParticleModel(ReferenceParametersType._GroupModel, min_occurs=1, max_occurs=1)
+
+
 
 ProblemActionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'SoapAction'), pyxb.binding.datatypes.anyURI, scope=ProblemActionType))
 
@@ -395,15 +431,3 @@ ProblemActionType._GroupModel = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(ProblemActionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'SoapAction')), min_occurs=0L, max_occurs=1)
     )
 ProblemActionType._ContentModel = pyxb.binding.content.ParticleModel(ProblemActionType._GroupModel, min_occurs=1, max_occurs=1)
-
-
-ReferenceParametersType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
-    )
-ReferenceParametersType._ContentModel = pyxb.binding.content.ParticleModel(ReferenceParametersType._GroupModel, min_occurs=1, max_occurs=1)
-
-
-MetadataType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
-    )
-MetadataType._ContentModel = pyxb.binding.content.ParticleModel(MetadataType._GroupModel, min_occurs=1, max_occurs=1)
