@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wstop.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:4e8dbbb71a72b67c5dc95d408f0b903c3981ba86
-# Generated 2012-06-15 14:42:59.177532 by PyXB version 1.1.4
+# Generated 2012-11-01 15:13:38.677555 by PyXB version 1.1.5
 # Namespace http://docs.oasis-open.org/wsn/t-1
 
 import pyxb
@@ -13,7 +13,7 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:4fabdd88-b722-11e1-bce9-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9f847ca6-2460-11e2-941a-c8600024e903')
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
@@ -59,62 +59,115 @@ def CreateFromDOM (node, default_namespace=None):
     return pyxb.binding.basis.element.AnyCreateFromDOM(node, _fallback_namespace=default_namespace)
 
 
-# List SimpleTypeDefinition
+# Atomic simple type: {http://docs.oasis-open.org/wsn/t-1}SimpleTopicExpression
+class SimpleTopicExpression (pyxb.binding.datatypes.QName):
+
+    """An atomic simple type."""
+
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'SimpleTopicExpression')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 173, 2)
+    _Documentation = None
+SimpleTopicExpression._InitializeFacetMap()
+Namespace.addCategoryObject('typeBinding', u'SimpleTopicExpression', SimpleTopicExpression)
+
+# List simple type: [anonymous]
 # superclasses pyxb.binding.datatypes.anySimpleType
 class STD_ANON (pyxb.binding.basis.STD_list):
 
     """Simple type that is a list of pyxb.binding.datatypes.QName."""
 
     _ExpandedName = None
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 109, 10)
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.QName
 STD_ANON._InitializeFacetMap()
 
-# Atomic SimpleTypeDefinition
-class ConcreteTopicExpression (pyxb.binding.datatypes.token):
-
-    """An atomic simple type."""
-
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ConcreteTopicExpression')
-    _Documentation = None
-ConcreteTopicExpression._CF_pattern = pyxb.binding.facets.CF_pattern()
-ConcreteTopicExpression._CF_pattern.addPattern(pattern=u'(([\\i-[:]][\\c-[:]]*:)?[\\i-[:]][\\c-[:]]*)(/([\\i-[:]][\\c-[:]]*:)?[\\i-[:]][\\c-[:]]*)*')
-ConcreteTopicExpression._InitializeFacetMap(ConcreteTopicExpression._CF_pattern)
-Namespace.addCategoryObject('typeBinding', u'ConcreteTopicExpression', ConcreteTopicExpression)
-
-# Atomic SimpleTypeDefinition
+# Atomic simple type: {http://docs.oasis-open.org/wsn/t-1}FullTopicExpression
 class FullTopicExpression (pyxb.binding.datatypes.token):
 
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'FullTopicExpression')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 138, 2)
     _Documentation = None
 FullTopicExpression._CF_pattern = pyxb.binding.facets.CF_pattern()
 FullTopicExpression._CF_pattern.addPattern(pattern=u'([\\i-[:]][\\c-[:]]*:)?(//)?([\\i-[:]][\\c-[:]]*|\\*)((/|//)(([\\i-[:]][\\c-[:]]*:)?[\\i-[:]][\\c-[:]]*|\\*|[.]))*(\\|([\\i-[:]][\\c-[:]]*:)?(//)?([\\i-[:]][\\c-[:]]*|\\*)((/|//)(([\\i-[:]][\\c-[:]]*:)?[\\i-[:]][\\c-[:]]*|\\*|[.]))*)*')
 FullTopicExpression._InitializeFacetMap(FullTopicExpression._CF_pattern)
 Namespace.addCategoryObject('typeBinding', u'FullTopicExpression', FullTopicExpression)
 
-# Atomic SimpleTypeDefinition
-class SimpleTopicExpression (pyxb.binding.datatypes.QName):
+# Atomic simple type: {http://docs.oasis-open.org/wsn/t-1}ConcreteTopicExpression
+class ConcreteTopicExpression (pyxb.binding.datatypes.token):
 
     """An atomic simple type."""
 
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'SimpleTopicExpression')
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ConcreteTopicExpression')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 156, 2)
     _Documentation = None
-SimpleTopicExpression._InitializeFacetMap()
-Namespace.addCategoryObject('typeBinding', u'SimpleTopicExpression', SimpleTopicExpression)
+ConcreteTopicExpression._CF_pattern = pyxb.binding.facets.CF_pattern()
+ConcreteTopicExpression._CF_pattern.addPattern(pattern=u'(([\\i-[:]][\\c-[:]]*:)?[\\i-[:]][\\c-[:]]*)(/([\\i-[:]][\\c-[:]]*:)?[\\i-[:]][\\c-[:]]*)*')
+ConcreteTopicExpression._InitializeFacetMap(ConcreteTopicExpression._CF_pattern)
+Namespace.addCategoryObject('typeBinding', u'ConcreteTopicExpression', ConcreteTopicExpression)
 
-# Complex type ExtensibleDocumented with content type ELEMENT_ONLY
+# Complex type {http://docs.oasis-open.org/wsn/t-1}QueryExpressionType with content type MIXED
+class QueryExpressionType (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'QueryExpressionType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 42, 0)
+    # Base type is pyxb.binding.datatypes.anyType
+    
+    # Attribute Dialect uses Python identifier Dialect
+    __Dialect = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Dialect'), 'Dialect', '__httpdocs_oasis_open_orgwsnt_1_QueryExpressionType_Dialect', pyxb.binding.datatypes.anyURI, required=True)
+    __Dialect._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 46, 2)
+    __Dialect._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 46, 2)
+    
+    Dialect = property(__Dialect.value, __Dialect.set, None, None)
+
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        __Dialect.name() : __Dialect
+    }
+Namespace.addCategoryObject('typeBinding', u'QueryExpressionType', QueryExpressionType)
+
+
+# Complex type {http://docs.oasis-open.org/wsn/t-1}Documentation with content type MIXED
+class Documentation (pyxb.binding.basis.complexTypeDefinition):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Documentation')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 26, 2)
+    # Base type is pyxb.binding.datatypes.anyType
+    _HasWildcardElement = True
+
+    _ElementMap = {
+        
+    }
+    _AttributeMap = {
+        
+    }
+Namespace.addCategoryObject('typeBinding', u'Documentation', Documentation)
+
+
+# Complex type {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented with content type ELEMENT_ONLY
 class ExtensibleDocumented (pyxb.binding.basis.complexTypeDefinition):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = True
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'ExtensibleDocumented')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 33, 2)
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://docs.oasis-open.org/wsn/t-1}documentation uses Python identifier documentation
     __documentation = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'documentation'), 'documentation', '__httpdocs_oasis_open_orgwsnt_1_ExtensibleDocumented_httpdocs_oasis_open_orgwsnt_1documentation', False)
+    __documentation._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 36, 6)
+    __documentation._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 35, 4)
 
     
     documentation = property(__documentation.value, __documentation.set, None, None)
@@ -130,40 +183,49 @@ class ExtensibleDocumented (pyxb.binding.basis.complexTypeDefinition):
 Namespace.addCategoryObject('typeBinding', u'ExtensibleDocumented', ExtensibleDocumented)
 
 
-# Complex type TopicNamespaceType with content type ELEMENT_ONLY
+# Complex type {http://docs.oasis-open.org/wsn/t-1}TopicNamespaceType with content type ELEMENT_ONLY
 class TopicNamespaceType (ExtensibleDocumented):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TopicNamespaceType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 50, 2)
     # Base type is ExtensibleDocumented
     
-    # Element documentation ({http://docs.oasis-open.org/wsn/t-1}documentation) inherited from {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented
-    
     # Element {http://docs.oasis-open.org/wsn/t-1}Topic uses Python identifier Topic
     __Topic = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Topic'), 'Topic', '__httpdocs_oasis_open_orgwsnt_1_TopicNamespaceType_httpdocs_oasis_open_orgwsnt_1Topic', True)
+    __Topic._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 54, 11)
+    __Topic._UseLocation = None
 
     
     Topic = property(__Topic.value, __Topic.set, None, None)
 
     
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpdocs_oasis_open_orgwsnt_1_TopicNamespaceType_name', pyxb.binding.datatypes.NCName)
-    
-    name = property(__name.value, __name.set, None, None)
-
+    # Element documentation ({http://docs.oasis-open.org/wsn/t-1}documentation) inherited from {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented
     
     # Attribute targetNamespace uses Python identifier targetNamespace
     __targetNamespace = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'targetNamespace'), 'targetNamespace', '__httpdocs_oasis_open_orgwsnt_1_TopicNamespaceType_targetNamespace', pyxb.binding.datatypes.anyURI, required=True)
+    __targetNamespace._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 69, 9)
+    __targetNamespace._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 69, 9)
     
     targetNamespace = property(__targetNamespace.value, __targetNamespace.set, None, None)
 
     
     # Attribute final uses Python identifier final
     __final = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'final'), 'final', '__httpdocs_oasis_open_orgwsnt_1_TopicNamespaceType_final', pyxb.binding.datatypes.boolean, unicode_default=u'false')
+    __final._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 71, 9)
+    __final._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 71, 9)
     
     final = property(__final.value, __final.set, None, None)
 
+    
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpdocs_oasis_open_orgwsnt_1_TopicNamespaceType_name', pyxb.binding.datatypes.NCName)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 68, 9)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 68, 9)
+    
+    name = property(__name.value, __name.set, None, None)
+
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://docs.oasis-open.org/wsn/t-1'))
     _HasWildcardElement = True
 
@@ -173,19 +235,89 @@ class TopicNamespaceType (ExtensibleDocumented):
     })
     _AttributeMap = ExtensibleDocumented._AttributeMap.copy()
     _AttributeMap.update({
-        __name.name() : __name,
         __targetNamespace.name() : __targetNamespace,
-        __final.name() : __final
+        __final.name() : __final,
+        __name.name() : __name
     })
 Namespace.addCategoryObject('typeBinding', u'TopicNamespaceType', TopicNamespaceType)
 
 
-# Complex type TopicSetType with content type ELEMENT_ONLY
+# Complex type {http://docs.oasis-open.org/wsn/t-1}TopicType with content type ELEMENT_ONLY
+class TopicType (ExtensibleDocumented):
+    _TypeDefinition = None
+    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
+    _Abstract = False
+    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TopicType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 90, 2)
+    # Base type is ExtensibleDocumented
+    
+    # Element documentation ({http://docs.oasis-open.org/wsn/t-1}documentation) inherited from {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented
+    
+    # Element {http://docs.oasis-open.org/wsn/t-1}MessagePattern uses Python identifier MessagePattern
+    __MessagePattern = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'MessagePattern'), 'MessagePattern', '__httpdocs_oasis_open_orgwsnt_1_TopicType_httpdocs_oasis_open_orgwsnt_1MessagePattern', False)
+    __MessagePattern._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 94, 10)
+    __MessagePattern._UseLocation = None
+
+    
+    MessagePattern = property(__MessagePattern.value, __MessagePattern.set, None, None)
+
+    
+    # Element {http://docs.oasis-open.org/wsn/t-1}Topic uses Python identifier Topic
+    __Topic = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Topic'), 'Topic', '__httpdocs_oasis_open_orgwsnt_1_TopicType_httpdocs_oasis_open_orgwsnt_1Topic', True)
+    __Topic._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 97, 10)
+    __Topic._UseLocation = None
+
+    
+    Topic = property(__Topic.value, __Topic.set, None, None)
+
+    
+    # Attribute final uses Python identifier final
+    __final = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'final'), 'final', '__httpdocs_oasis_open_orgwsnt_1_TopicType_final', pyxb.binding.datatypes.boolean, unicode_default=u'false')
+    __final._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 113, 8)
+    __final._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 113, 8)
+    
+    final = property(__final.value, __final.set, None, None)
+
+    
+    # Attribute messageTypes uses Python identifier messageTypes
+    __messageTypes = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'messageTypes'), 'messageTypes', '__httpdocs_oasis_open_orgwsnt_1_TopicType_messageTypes', STD_ANON)
+    __messageTypes._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 108, 8)
+    __messageTypes._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 108, 8)
+    
+    messageTypes = property(__messageTypes.value, __messageTypes.set, None, None)
+
+    
+    # Attribute name uses Python identifier name
+    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpdocs_oasis_open_orgwsnt_1_TopicType_name', pyxb.binding.datatypes.NCName, required=True)
+    __name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 107, 8)
+    __name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 107, 8)
+    
+    name = property(__name.value, __name.set, None, None)
+
+    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://docs.oasis-open.org/wsn/t-1'))
+    _HasWildcardElement = True
+
+    _ElementMap = ExtensibleDocumented._ElementMap.copy()
+    _ElementMap.update({
+        __MessagePattern.name() : __MessagePattern,
+        __Topic.name() : __Topic
+    })
+    _AttributeMap = ExtensibleDocumented._AttributeMap.copy()
+    _AttributeMap.update({
+        __final.name() : __final,
+        __messageTypes.name() : __messageTypes,
+        __name.name() : __name
+    })
+Namespace.addCategoryObject('typeBinding', u'TopicType', TopicType)
+
+
+# Complex type {http://docs.oasis-open.org/wsn/t-1}TopicSetType with content type ELEMENT_ONLY
 class TopicSetType (ExtensibleDocumented):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TopicSetType')
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 121, 2)
     # Base type is ExtensibleDocumented
     
     # Element documentation ({http://docs.oasis-open.org/wsn/t-1}documentation) inherited from {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented
@@ -203,70 +335,13 @@ class TopicSetType (ExtensibleDocumented):
 Namespace.addCategoryObject('typeBinding', u'TopicSetType', TopicSetType)
 
 
-# Complex type TopicType with content type ELEMENT_ONLY
-class TopicType (ExtensibleDocumented):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TopicType')
-    # Base type is ExtensibleDocumented
-    
-    # Element documentation ({http://docs.oasis-open.org/wsn/t-1}documentation) inherited from {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented
-    
-    # Element {http://docs.oasis-open.org/wsn/t-1}MessagePattern uses Python identifier MessagePattern
-    __MessagePattern = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'MessagePattern'), 'MessagePattern', '__httpdocs_oasis_open_orgwsnt_1_TopicType_httpdocs_oasis_open_orgwsnt_1MessagePattern', False)
-
-    
-    MessagePattern = property(__MessagePattern.value, __MessagePattern.set, None, None)
-
-    
-    # Element {http://docs.oasis-open.org/wsn/t-1}Topic uses Python identifier Topic
-    __Topic = pyxb.binding.content.ElementUse(pyxb.namespace.ExpandedName(Namespace, u'Topic'), 'Topic', '__httpdocs_oasis_open_orgwsnt_1_TopicType_httpdocs_oasis_open_orgwsnt_1Topic', True)
-
-    
-    Topic = property(__Topic.value, __Topic.set, None, None)
-
-    
-    # Attribute messageTypes uses Python identifier messageTypes
-    __messageTypes = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'messageTypes'), 'messageTypes', '__httpdocs_oasis_open_orgwsnt_1_TopicType_messageTypes', STD_ANON)
-    
-    messageTypes = property(__messageTypes.value, __messageTypes.set, None, None)
-
-    
-    # Attribute final uses Python identifier final
-    __final = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'final'), 'final', '__httpdocs_oasis_open_orgwsnt_1_TopicType_final', pyxb.binding.datatypes.boolean, unicode_default=u'false')
-    
-    final = property(__final.value, __final.set, None, None)
-
-    
-    # Attribute name uses Python identifier name
-    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'name'), 'name', '__httpdocs_oasis_open_orgwsnt_1_TopicType_name', pyxb.binding.datatypes.NCName, required=True)
-    
-    name = property(__name.value, __name.set, None, None)
-
-    _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://docs.oasis-open.org/wsn/t-1'))
-    _HasWildcardElement = True
-
-    _ElementMap = ExtensibleDocumented._ElementMap.copy()
-    _ElementMap.update({
-        __MessagePattern.name() : __MessagePattern,
-        __Topic.name() : __Topic
-    })
-    _AttributeMap = ExtensibleDocumented._AttributeMap.copy()
-    _AttributeMap.update({
-        __messageTypes.name() : __messageTypes,
-        __final.name() : __final,
-        __name.name() : __name
-    })
-Namespace.addCategoryObject('typeBinding', u'TopicType', TopicType)
-
-
-# Complex type CTD_ANON with content type ELEMENT_ONLY
+# Complex type [anonymous] with content type ELEMENT_ONLY
 class CTD_ANON (TopicType):
     _TypeDefinition = None
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
+    _DefinitionLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 56, 14)
     # Base type is TopicType
     
     # Element documentation ({http://docs.oasis-open.org/wsn/t-1}documentation) inherited from {http://docs.oasis-open.org/wsn/t-1}ExtensibleDocumented
@@ -275,17 +350,19 @@ class CTD_ANON (TopicType):
     
     # Element Topic ({http://docs.oasis-open.org/wsn/t-1}Topic) inherited from {http://docs.oasis-open.org/wsn/t-1}TopicType
     
-    # Attribute messageTypes inherited from {http://docs.oasis-open.org/wsn/t-1}TopicType
-    
     # Attribute final inherited from {http://docs.oasis-open.org/wsn/t-1}TopicType
     
+    # Attribute name inherited from {http://docs.oasis-open.org/wsn/t-1}TopicType
+    
+    # Attribute messageTypes inherited from {http://docs.oasis-open.org/wsn/t-1}TopicType
+    
     # Attribute parent uses Python identifier parent
     __parent = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'parent'), 'parent', '__httpdocs_oasis_open_orgwsnt_1_CTD_ANON_parent', ConcreteTopicExpression)
+    __parent._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 59, 19)
+    __parent._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.RHB65sy/PyXB-1.1.5/pyxb/bundles/wssplat/schemas/wstop.xsd', 59, 19)
     
     parent = property(__parent.value, __parent.set, None, None)
 
-    
-    # Attribute name inherited from {http://docs.oasis-open.org/wsn/t-1}TopicType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://docs.oasis-open.org/wsn/t-1'))
     _HasWildcardElement = True
 
@@ -300,48 +377,6 @@ class CTD_ANON (TopicType):
 
 
 
-# Complex type Documentation with content type MIXED
-class Documentation (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Documentation')
-    # Base type is pyxb.binding.datatypes.anyType
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        
-    }
-Namespace.addCategoryObject('typeBinding', u'Documentation', Documentation)
-
-
-# Complex type QueryExpressionType with content type MIXED
-class QueryExpressionType (pyxb.binding.basis.complexTypeDefinition):
-    _TypeDefinition = None
-    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
-    _Abstract = False
-    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'QueryExpressionType')
-    # Base type is pyxb.binding.datatypes.anyType
-    
-    # Attribute Dialect uses Python identifier Dialect
-    __Dialect = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Dialect'), 'Dialect', '__httpdocs_oasis_open_orgwsnt_1_QueryExpressionType_Dialect', pyxb.binding.datatypes.anyURI, required=True)
-    
-    Dialect = property(__Dialect.value, __Dialect.set, None, None)
-
-    _HasWildcardElement = True
-
-    _ElementMap = {
-        
-    }
-    _AttributeMap = {
-        __Dialect.name() : __Dialect
-    }
-Namespace.addCategoryObject('typeBinding', u'QueryExpressionType', QueryExpressionType)
-
-
 TopicNamespace = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'TopicNamespace'), TopicNamespaceType)
 Namespace.addCategoryObject('elementBinding', TopicNamespace.name().localName(), TopicNamespace)
 
@@ -349,6 +384,18 @@ TopicSet = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'T
 Namespace.addCategoryObject('elementBinding', TopicSet.name().localName(), TopicSet)
 
 
+QueryExpressionType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=1L)
+    )
+QueryExpressionType._ContentModel = pyxb.binding.content.ParticleModel(QueryExpressionType._GroupModel, min_occurs=1, max_occurs=1)
+
+
+Documentation._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
+    )
+Documentation._ContentModel = pyxb.binding.content.ParticleModel(Documentation._GroupModel, min_occurs=1, max_occurs=1)
+
+
 
 ExtensibleDocumented._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'documentation'), Documentation, scope=ExtensibleDocumented))
 ExtensibleDocumented._GroupModel = pyxb.binding.content.GroupSequence(
@@ -373,19 +420,6 @@ TopicNamespaceType._GroupModel = pyxb.binding.content.GroupSequence(
 TopicNamespaceType._ContentModel = pyxb.binding.content.ParticleModel(TopicNamespaceType._GroupModel, min_occurs=1, max_occurs=1)
 
 
-TopicSetType._GroupModel_ = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(TopicSetType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'documentation')), min_occurs=0L, max_occurs=1)
-    )
-TopicSetType._GroupModel_2 = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://docs.oasis-open.org/wsn/t-1')), min_occurs=0L, max_occurs=None)
-    )
-TopicSetType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(TopicSetType._GroupModel_, min_occurs=1, max_occurs=1),
-    pyxb.binding.content.ParticleModel(TopicSetType._GroupModel_2, min_occurs=1, max_occurs=1)
-    )
-TopicSetType._ContentModel = pyxb.binding.content.ParticleModel(TopicSetType._GroupModel, min_occurs=1, max_occurs=1)
-
-
 
 TopicType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'MessagePattern'), QueryExpressionType, scope=TopicType))
 
@@ -405,6 +439,19 @@ TopicType._GroupModel = pyxb.binding.content.GroupSequence(
 TopicType._ContentModel = pyxb.binding.content.ParticleModel(TopicType._GroupModel, min_occurs=1, max_occurs=1)
 
 
+TopicSetType._GroupModel_ = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(TopicSetType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'documentation')), min_occurs=0L, max_occurs=1)
+    )
+TopicSetType._GroupModel_2 = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://docs.oasis-open.org/wsn/t-1')), min_occurs=0L, max_occurs=None)
+    )
+TopicSetType._GroupModel = pyxb.binding.content.GroupSequence(
+    pyxb.binding.content.ParticleModel(TopicSetType._GroupModel_, min_occurs=1, max_occurs=1),
+    pyxb.binding.content.ParticleModel(TopicSetType._GroupModel_2, min_occurs=1, max_occurs=1)
+    )
+TopicSetType._ContentModel = pyxb.binding.content.ParticleModel(TopicSetType._GroupModel, min_occurs=1, max_occurs=1)
+
+
 CTD_ANON._GroupModel_ = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'documentation')), min_occurs=0L, max_occurs=1)
     )
@@ -418,15 +465,3 @@ CTD_ANON._GroupModel = pyxb.binding.content.GroupSequence(
     pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel_2, min_occurs=1, max_occurs=1)
     )
 CTD_ANON._ContentModel = pyxb.binding.content.ParticleModel(CTD_ANON._GroupModel, min_occurs=1, max_occurs=1)
-
-
-Documentation._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=None)
-    )
-Documentation._ContentModel = pyxb.binding.content.ParticleModel(Documentation._GroupModel, min_occurs=1, max_occurs=1)
-
-
-QueryExpressionType._GroupModel = pyxb.binding.content.GroupSequence(
-    pyxb.binding.content.ParticleModel(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), min_occurs=0L, max_occurs=1L)
-    )
-QueryExpressionType._ContentModel = pyxb.binding.content.ParticleModel(QueryExpressionType._GroupModel, min_occurs=1, max_occurs=1)
