@@ -1,4 +1,5 @@
-# Copyright 2009, Peter A. Bigot
+# -*- coding: utf-8 -*-
+# Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain a
@@ -17,9 +18,11 @@ Namespaces<http://www.w3.org/TR/2006/REC-xml-names-20060816/index.html>}."""
 
 import pyxb
 import os
-import fnmatch
+import os.path
 import pyxb.utils.utility
-import utility
+import logging
+
+_log = logging.getLogger(__name__)
 
 PathEnvironmentVariable = 'PYXB_ARCHIVE_PATH'
 """Environment variable from which default path to pre-loaded namespaces is
@@ -32,22 +35,16 @@ with PyXB.
 @note: If you put a path separator between C{&} and the following path, this
 will cause the substitution to be ignored."""
 
-import os.path
-import stat
-
 DefaultArchivePrefix = os.path.realpath(os.path.join(os.path.dirname( __file__), '../..'))
 """The default archive prefix, substituted for C{&} in C{PYXB_ARCHIVE_PATH}."""
 
 def GetArchivePath ():
     """Return the archive path as defined by the L{PathEnvironmentVariable},
     or C{None} if that variable is not defined."""
-    import os
     return os.environ.get(PathEnvironmentVariable)
 
 # Stuff required for pickling
 import cPickle as pickle
-#import pyxb.utils.pickle_trace as pickle
-
 import re
 
 class NamespaceArchive (object):
@@ -121,10 +118,12 @@ class NamespaceArchive (object):
         This only validates potential archive contents; it does not load
         namespace data from the archives.  If invoked with no arguments, 
 
-        @keyword archive_path: A colon-separated list of files or directories in
-        which namespace archives can be found; see L{PathEnvironmentVariable}.
-        Defaults to L{GetArchivePath()}.  If not defaulted, C{reset} will be
-        forced to C{True}.  For any directory in the path, all files ending with
+        @keyword archive_path: A list of files or directories in which
+        namespace archives can be found.  The entries are separated by
+        os.pathsep, which is a colon on POSIX platforms and a semi-colon on
+        Windows.  See L{PathEnvironmentVariable}.  Defaults to
+        L{GetArchivePath()}.  If not defaulted, C{reset} will be forced to
+        C{True}.  For any directory in the path, all files ending with
         C{.wxs} are examined.
 
         @keyword required_archive_files: A list of paths to files that must
@@ -142,7 +141,7 @@ class NamespaceArchive (object):
         contain a valid namespace archive.
         """
         
-        import builtin
+        from pyxb.namespace import builtin
         
         reset = reset or (archive_path is not None) or (required_archive_files is not None) or (cls.__NamespaceArchives is None)
         required_archives = []
@@ -169,14 +168,13 @@ class NamespaceArchive (object):
                                                                       default_path_wildcard='+', default_path=GetArchivePath(),
                                                                       prefix_pattern='&', prefix_substituend=DefaultArchivePrefix)
                 for afn in candidate_files:
-                    #print 'Considering %s' % (afn,)
                     try:
                         nsa = cls.__GetArchiveInstance(afn, stage=cls._STAGE_readModules)
                         archive_set.add(nsa)
                     except pickle.UnpicklingError, e:
-                        print 'Cannot use archive %s: %s' % (afn, e)
+                        _log.exception('Cannot unpickle archive %s', afn)
                     except pyxb.NamespaceArchiveError, e:
-                        print 'Cannot use archive %s: %s' % (afn, e)
+                        _log.exception('Cannot process archive %s', afn)
                 
                 # Do this for two reasons: first, to get an iterable that won't
                 # cause problems when we remove unresolvable archives from
@@ -198,13 +196,11 @@ class NamespaceArchive (object):
                                 continue
                             da = archive_map.get(p)
                             if da is None:
-                                print 'WARNING: %s depends on unavailable archive %s' % (a, p)
+                                _log.warning('%s depends on unavailable archive %s', a, p)
                                 archive_set.remove(a)
                             else:
-                                #print '%s depends on %s' % (a, da)
                                 archive_graph.addEdge(a, da)
                     else:
-                        #print '%s has no dependencies' % (a,)
                         archive_graph.addRoot(a)
     
                 # Verify that there are no dependency loops.
@@ -214,18 +210,16 @@ class NamespaceArchive (object):
                         raise pyxb.LogicError("Cycle in archive dependencies.  How'd you do that?\n  " + "\n  ".join([ _a.archivePath() for _a in scc ]))
                     archive = scc[0]
                     if not (archive in archive_set):
-                        #print 'Discarding unresolvable %s' % (archive,)
                         archive.discard()
                         existing_archives.remove(archive)
                         continue
-                    #print 'Completing load of %s' % (archive,)
                     #archive._readToStage(cls._STAGE_COMPLETE)
 
             # Discard any archives that we used to know about but now aren't
             # supposed to.  @todo make this friendlier in the case of archives
             # we've already incorporated.
             for archive in existing_archives.difference(archive_set):
-                print 'Discarding excluded archive %s' % (archive,)
+                _log.info('Discarding excluded archive %s', archive)
                 archive.discard()
 
         return required_archives
@@ -349,16 +343,15 @@ class NamespaceArchive (object):
     def __createUnpickler (self):
         unpickler = pickle.Unpickler(open(self.__archivePath, 'rb'))
 
-        format = unpickler.load()
-        if self.__PickleFormat != format:
-            raise pyxb.NamespaceArchiveError('Archive format is %s, require %s' % (format, self.__PickleFormat))
+        fmt = unpickler.load()
+        if self.__PickleFormat != fmt:
+            raise pyxb.NamespaceArchiveError('Archive format is %s, require %s' % (fmt, self.__PickleFormat))
 
         self.__generationUID = unpickler.load()
 
         return unpickler
 
     def __readModules (self, unpickler):
-        #print 'RM %x %s' % (id(self), self)
         mrs = unpickler.load()
         assert isinstance(mrs, set), 'Expected set got %s from %s' % (type(mrs), self.archivePath())
         if self.__moduleRecords is None:
@@ -366,7 +359,6 @@ class NamespaceArchive (object):
                 mr2 = mr.namespace().lookupModuleRecordByUID(mr.generationUID())
                 if mr2 is not None:
                     mr2._setFromOther(mr, self)
-                    #print 'Replaced locally defined %s with archive data' % (mr2,)
                     mrs.remove(mr)
             self.__moduleRecords = set()
             assert 0 == len(self.__namespaces)
@@ -386,55 +378,44 @@ class NamespaceArchive (object):
     def _unsatisfiedModulePrerequisites (self):
         prereq_uids = set()
         for mr in self.__moduleRecords:
-            ns = mr.namespace()
-            #print 'Namespace %s records:' % (ns,)
-            #for xmr in ns.moduleRecords():
-            #    print ' %s' % (xmr,)
             prereq_uids.update(mr.dependsOnExternal())
         return prereq_uids
 
     def __validatePrerequisites (self, stage):
-        import builtin
+        from pyxb.namespace import builtin
         prereq_uids = self._unsatisfiedModulePrerequisites()
-        #print '%s depends on %d prerequisites' % (self, len(prereq_uids))
         for uid in prereq_uids:
             if builtin.BuiltInObjectUID == uid:
                 continue
             depends_on = self.__NamespaceArchives.get(uid)
             if depends_on is None:
                 raise pyxb.NamespaceArchiveError('%s: archive depends on unavailable archive %s' % (self.archivePath(), uid))
-            #print '%s stage %s depends on %s at %s going to %s' % (self, self._stage(), depends_on, depends_on._stage(), stage)
             depends_on._readToStage(stage)
 
     def __validateModules (self):
         self.__validatePrerequisites(self._STAGE_validateModules)
         for mr in self.__moduleRecords:
             ns = mr.namespace()
-            #print 'Namespace %s records:' % (ns,)
-            #for xmr in ns.moduleRecords():
-            #    print ' %s' % (xmr,)
             for base_uid in mr.dependsOnExternal():
                 xmr = ns.lookupModuleRecordByUID(base_uid)
                 if xmr is None:
                     raise pyxb.NamespaceArchiveError('Module %s depends on external module %s, not available in archive path' % (mr.generationUID(), base_uid))
                 if not xmr.isIncorporated():
-                    print 'Need to incorporate data from %s' % (xmr,)
+                    _log.info('Need to incorporate data from %s', xmr)
                 else:
-                    print 'Have required base data %s' % (xmr,)
+                    _log.info('Have required base data %s', xmr)
 
             for origin in mr.origins():
-                #print 'mr %s origin %s' % (mr, origin)
                 for (cat, names) in origin.categoryMembers().iteritems():
                     if not (cat in ns.categories()):
                         continue
                     cross_objects = names.intersection(ns.categoryMap(cat).keys())
                     if 0 < len(cross_objects):
                         raise pyxb.NamespaceArchiveError('Archive %s namespace %s module %s origin %s archive/active conflict on category %s: %s' % (self.__archivePath, ns, mr, origin, cat, " ".join(cross_objects)))
-                    print '%s no conflicts on %d names' % (cat, len(names))
+                    _log.info('%s no conflicts on %d names', cat, len(names))
 
     def __readComponentSet (self, unpickler):
         self.__validatePrerequisites(self._STAGE_readComponents)
-        print 'RCS %s' % (self,)
         for n in range(len(self.__moduleRecords)):
             ns = unpickler.load()
             mr = ns.lookupModuleRecordByUID(self.generationUID())
@@ -449,7 +430,6 @@ class NamespaceArchive (object):
             raise pyxb.NamespaceArchiveError('Attempt to read from invalid archive %s' % (self,))
         try:
             while self.__stage < stage:
-                #print 'RTS %s want %s' % (self.__stage, stage)
                 if self.__stage < self._STAGE_uid:
                     self.__unpickler = self.__createUnpickler()
                     self.__stage = self._STAGE_uid
@@ -506,7 +486,6 @@ class NamespaceArchive (object):
             pickler = self.__createPickler(output)
 
             assert isinstance(self.__moduleRecords, set)
-            print "\n".join([ str(_mr) for _mr in self.__moduleRecords ])
             pickler.dump(self.__moduleRecords)
 
             for mr in self.__moduleRecords:
@@ -555,7 +534,7 @@ class _ArchivableObject_mixin (pyxb.cscRoot):
         return self._updateFromOther_csc(other)
 
     def _allowUpdateFromOther (self, other):
-        import builtin
+        from pyxb.namespace import builtin
         assert self._objectOrigin()
         return builtin.BuiltInObjectUID == self._objectOrigin().generationUID()
 
@@ -584,14 +563,11 @@ class _NamespaceArchivable_mixin (pyxb.cscRoot):
         if self.__isActive and empty_inactive:
             for (ct, cm) in self._categoryMap().items():
                 if 0 < len(cm):
-                    print '%s: %d %s -- activated' % (self, len(cm), ct)
                     return True
             return False
         return self.__isActive
 
     def _activate (self):
-        #if not self.__isActive:
-        #    print 'Activating %s' % (self,)
         self.__isActive = True
     __isActive = None
 
@@ -608,7 +584,6 @@ class _NamespaceArchivable_mixin (pyxb.cscRoot):
         # Yes, I do want this to raise KeyError if the archive is not present
         mr = self.__moduleRecordMap[archive.generationUID()]
         assert not mr.isIncorporated(), 'Removing archive %s after incorporation' % (archive.archivePath(),)
-        # print 'removing %s' % (mr,)
         del self.__moduleRecordMap[archive.generationUID()]
         
     def isLoadable (self):
@@ -765,11 +740,10 @@ class ModuleRecord (pyxb.utils.utility.PrivateTransient_mixin):
     __PrivateTransient.add('constructedLocally')
 
     def __init__ (self, namespace, generation_uid, **kw):
-        import builtin
+        from pyxb.namespace import builtin
 
         super(ModuleRecord, self).__init__()
         self.__namespace = namespace
-        #print 'Created MR for %s gen %s' % (namespace, generation_uid)
         assert (generation_uid != builtin.BuiltInObjectUID) or namespace.isBuiltinNamespace()
         self.__isPublic = kw.get('is_public', False)
         self.__isIncoporated = kw.get('is_incorporated', False)
@@ -840,13 +814,12 @@ class ModuleRecord (pyxb.utils.utility.PrivateTransient_mixin):
         self.__dependsOnExternal.clear()
         for mr in ns.moduleRecords():
             if mr != self:
-                print 'This gen depends on %s' % (mr,)
+                _log.info('This gen depends on %s', mr)
                 self.__dependsOnExternal.add(mr.generationUID())
         for obj in ns._namedObjects().union(ns.components()):
             if isinstance(obj, _ArchivableObject_mixin):
                 if obj._objectOrigin():
                     obj._prepareForArchive(self)
-        #print 'Archive %s ns %s module %s has %d origins' % (self.archive(), self.namespace(), self, len(self.origins()))
 
     def completeGenerationAssociations (self):
         self.namespace()._transferReferencedNamespaces(self)
@@ -979,17 +952,6 @@ class _SchemaOrigin (_ObjectOrigin):
         rv.append(')')
         return ''.join(rv)
 
-def AvailableForLoad ():
-    """Return a list of namespace URIs for which we may be able to load the
-    namespace contents from a pre-parsed file.  The corresponding L{Namespace}
-    can be retrieved using L{NamespaceForURI}, and the declared objects in
-    that namespace loaded with L{Namespace.validateComponentModel}.
-
-    Note that success of the load is not guaranteed if the packed file
-    is not compatible with the schema class being used."""
-    # Invoke this to ensure we have searched for loadable namespaces
-    return _LoadableNamespaceMap().keys()
-
 class NamespaceDependencies (object):
 
     def rootNamespaces (self):
@@ -1013,7 +975,7 @@ class NamespaceDependencies (object):
                     if not rns in done_check:
                         need_check.add(rns)
                 if not ns.hasSchemaComponents():
-                    print 'WARNING: Referenced %s has no schema components' % (ns.uri(),)
+                    _log.warning('Referenced %s has no schema components', ns.uri())
                 done_check.add(ns)
             assert done_check == self.__namespaceGraph.nodes()
 
