@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -19,6 +20,9 @@ import pyxb.namespace
 import pyxb.utils.saxutils
 import pyxb.utils.saxdom
 import xml.dom
+import logging
+
+_log = logging.getLogger(__name__)
 
 # The DOM implementation to be used for all processing.  Default is whatever
 # your Python install uses.  If it's minidom, it should work.
@@ -51,8 +55,7 @@ def StringToDOM (text, **kw):
     if pyxb.XMLStyle_minidom == pyxb._XMLStyle:
         parser = pyxb.utils.saxutils.make_parser()
         return xml.dom.minidom.parseString(text, parser)
-    import saxdom
-    return saxdom.parseString(text, **kw)
+    return pyxb.utils.saxdom.parseString(text, **kw)
 
 def NodeAttribute (node, attribute_ncname, attribute_ns=None):
     """Namespace-aware search for an optional attribute in a node.
@@ -101,10 +104,10 @@ def LocateUniqueChild (node, tag, absent_ok=True, namespace=pyxb.namespace.XMLSc
     for cn in node.childNodes:
         if (xml.dom.Node.ELEMENT_NODE == cn.nodeType) and namespace.nodeIsNamed(cn, tag):
             if candidate:
-                raise pyxb.SchemaValidationError('Multiple %s elements nested in %s' % (name, node.nodeName))
+                raise pyxb.SchemaValidationError('Multiple %s elements nested in %s' % (tag, node.nodeName))
             candidate = cn
     if (candidate is None) and not absent_ok:
-        raise pyxb.SchemaValidationError('Expected %s elements nested in %s' % (name, node.nodeName))
+        raise pyxb.SchemaValidationError('Expected %s elements nested in %s' % (tag, node.nodeName))
     return candidate
 
 def LocateMatchingChildren (node, tag, namespace=pyxb.namespace.XMLSchema):
@@ -270,6 +273,8 @@ class _BDSNamespaceSupport (object):
             raise pyxb.UsageError('declareNamespace: must be given a namespace instance')
         if namespace.isAbsentNamespace():
             raise pyxb.UsageError('declareNamespace: namespace must not be an absent namespace')
+        if prefix is None:
+            prefix = self.__namespaces.get(namespace)
         if prefix is None:
             prefix = self.__namespacePrefixMap.get(namespace)
         if prefix is None:
@@ -277,11 +282,12 @@ class _BDSNamespaceSupport (object):
         if prefix is None:
             self.__namespacePrefixCounter += 1
             prefix = 'ns%d' % (self.__namespacePrefixCounter,)
+        if prefix == self.__namespaces.get(namespace):
+            return prefix
         if prefix in self.__prefixes:
             raise pyxb.LogicError('Prefix %s is already in use' % (prefix,))
         self.__namespaces[namespace] = prefix
         self.__prefixes.add(prefix)
-        #print '%x declared namespace %s as %s' % (id(self), namespace, prefix)
         if add_to_map:
             self.__namespacePrefixMap[namespace] = prefix
         return prefix
@@ -406,9 +412,9 @@ class BindingDOMSupport (object):
         self.__namespaceSupport.reset(**kw)
 
     @classmethod
-    def Reset (self, **kw):
+    def Reset (cls, **kw):
         """Reset the global defaults for default/prefix/namespace informmation."""
-        self.__NamespaceSupport.reset(**kw)
+        cls.__NamespaceSupport.reset(**kw)
 
     def __init__ (self, implementation=None, default_namespace=None, require_xsi_type=False, namespace_prefix_map=None):
         """Create a new instance used for building a single document.
@@ -462,7 +468,7 @@ class BindingDOMSupport (object):
 
     def declareNamespace (self, namespace, prefix=None):
         """Declare a namespace within this instance only."""
-        return self.__namespaceSupport.declareNamespace(namespace, prefix)
+        return self.__namespaceSupport.declareNamespace(namespace, prefix, add_to_map=True)
     @classmethod
     def DeclareNamespace (cls, namespace, prefix=None):
         """Declare a namespace that will be added to each created instance."""
@@ -575,7 +581,7 @@ class BindingDOMSupport (object):
         pfx = None
         local_name = name
         if 0 < name.find(':'):
-            (pfx, local_name) = node_name.split(':', 1)
+            (pfx, local_name) = name.split(':', 1)
             if ns is None:
                 raise pyxb.LogicError('QName with prefix but no available namespace')
         ns_uri = None
