@@ -1,4 +1,5 @@
-# Copyright 2009, Peter A. Bigot
+# -*- coding: utf-8 -*-
+# Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain a
@@ -24,6 +25,10 @@ element in the stream.  These classes are extended for specific parsing needs
 import xml.sax
 import xml.sax.handler
 import pyxb.namespace
+import StringIO
+import logging
+
+_log = logging.getLogger(__name__)
 
 class TracingSAXHandler (xml.sax.handler.ContentHandler):
     """A SAX handler class which prints each method invocation.
@@ -33,31 +38,31 @@ class TracingSAXHandler (xml.sax.handler.ContentHandler):
     __trace = False
 
     def setDocumentLocator (self, locator):
-        print 'setDocumentLocator %s' % (locator,)
+        _log.debug('setDocumentLocator %s', locator)
 
     def startDocument (self):
-        print 'startDocument'
+        _log.debug('startDocument')
 
     def startPrefixMapping (self, prefix, uri):
-        print 'startPrefixMapping %s %s' % (prefix, uri)
+        _log.debug('startPrefixMapping %s %s', prefix, uri)
 
     def endPrefixMapping (self, prefix):
-        print 'endPrefixMapping %s' % (prefix,)
+        _log.debug('endPrefixMapping %s', prefix)
 
     def startElementNS (self, name, qname, attrs):
-        print 'startElementNS %s %s' % (name, qname)
+        _log.debug('startElementNS %s %s', name, qname)
 
     def endElementNS (self, name, qname):
-        print 'endElementNS %s %s' % (name, qname)
+        _log.debug('endElementNS %s %s', name, qname)
 
     def characters (self, content):
-        print 'characters %s' % (content,)
+        _log.debug('characters %s', content)
 
     def ignorableWhitespace (self, whitespace):
-        print 'ignorableWhitespace len %d' % (len(whitespace),)
+        _log.debug('ignorableWhitespace len %d', len(whitespace))
 
-    def processingInstruction (self, data):
-        print 'processingInstruction %s' % (data,)
+    def processingInstruction (self, target, data):
+        _log.debug('processingInstruction %s %s', target, data)
 
 class _NoopSAXHandler (xml.sax.handler.ContentHandler):
     """A SAX handler class which doesn't do anything.  Used to get baseline
@@ -88,7 +93,7 @@ class _NoopSAXHandler (xml.sax.handler.ContentHandler):
     def ignorableWhitespace (self, whitespace):
         pass
 
-    def processingInstruction (self, data):
+    def processingInstruction (self, target, data):
         pass
 
 
@@ -295,7 +300,6 @@ class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
         @note: For this to be invoked, the C{feature_namespaces} feature must
         be enabled in the SAX parser."""
         self.__updateNamespaceContext().processXMLNS(prefix, uri)
-        #print '%s PM %s %s' % (self.__namespaceContext, prefix, uri)
 
     # The NamespaceContext management does not require any action upon
     # leaving the scope of a namespace directive.
@@ -361,12 +365,11 @@ class BaseSAXHandler (xml.sax.handler.ContentHandler, object):
 
     def ignorableWhitespace (self, whitespace):
         """Save whitespace as content too."""
-        self.__pendingText.append(content)
+        self.__pendingText.append(whitespace)
 
     def processingInstruction (self, target, data):
         self.__flushPendingText()
 
-import StringIO
 class _EntityResolver (object):
     """Dummy used to prevent the SAX parser from crashing when it sees
     processing instructions that we don't care about."""
@@ -442,12 +445,10 @@ def make_parser (**kw):
 
 if '__main__' == __name__:
     import xml.dom.pulldom
-    import pyxb.utils.domutils as domutils
     import pyxb.utils.saxdom as saxdom
     import time
     import lxml.sax
     import lxml.etree
-    import StringIO
     import sys
 
     Handler = BaseSAXHandler
