@@ -1,4 +1,5 @@
-# Copyright 2009, Peter A. Bigot
+# -*- coding: utf-8 -*-
+# Copyright 2009-2012, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain a
@@ -18,10 +19,12 @@ import re
 import os
 import errno
 import pyxb
+import urlparse
+import time
+import datetime
+import logging
 
-# Import utility routines that are not from PyXB so have distinct
-# licensing.
-from pyxb.utils.activestate import *
+_log = logging.getLogger(__name__)
 
 def QuotedEscaped (s):
     """Convert a string into a literal value that can be used in Python source.
@@ -108,7 +111,7 @@ def MakeIdentifier (s, camel_case=False):
     @rtype: C{str}
     """
     s = _XMLIdentifierToPython(s)
-    s = _PrefixUnderscore_re.sub('', _NonIdentifier_re.sub('',_UnderscoreSubstitute_re.sub('_', s)))
+    s = _PrefixUnderscore_re.sub('', _NonIdentifier_re.sub('', _UnderscoreSubstitute_re.sub('_', s)))
     if camel_case:
         s = _CamelCase_re.sub(lambda _m: _m.group(0)[1].upper(), s)
     if _PrefixDigit_re.match(s):
@@ -430,14 +433,11 @@ class Graph:
         source = v
         for target in self.__edgeMap.get(source, []):
             if self.__tarjanIndex[target] is None:
-                #print "Target %s not found in processed" % (target,)
                 self._tarjan(target)
                 self.__tarjanLowLink[v] = min(self.__tarjanLowLink[v], self.__tarjanLowLink[target])
             elif target in self.__stack:
-                #print "Found %s in stack" % (target,)
                 self.__tarjanLowLink[v] = min(self.__tarjanLowLink[v], self.__tarjanLowLink[target])
             else:
-                #print "No %s in stack" % (target,)
                 pass
 
         if self.__tarjanLowLink[v] == self.__tarjanIndex[v]:
@@ -445,12 +445,11 @@ class Graph:
             while True:
                 scc.append(self.__stack.pop())
                 if v == scc[-1]:
-                    break;
+                    break
             self.__sccOrder.append(scc)
             if 1 < len(scc):
                 self.__scc.append(scc)
                 [ self.__sccMap.setdefault(_v, scc) for _v in scc ]
-                #print 'SCC at %s' % (' '.join( [str(_s) for _s in scc ]),)
 
     def scc (self, reset=False):
         """Return the strongly-connected components of the graph.
@@ -594,9 +593,6 @@ def NormalizeLocation (uri, parent_uri=None, prefix_map=None):
     L{SetLocationPrefixRewriteMap}.
     
     """
-    import urlparse
-    import os
-    
     if uri is None:
         return uri
     if parent_uri is None:
@@ -614,7 +610,6 @@ def NormalizeLocation (uri, parent_uri=None, prefix_map=None):
         abs_uri = os.path.realpath(abs_uri)
     return abs_uri
 
-import urlparse
 
 def TextFromURI (uri, archive_directory=None):
     """Retrieve the contents of the uri as a text string.
@@ -649,7 +644,7 @@ def TextFromURI (uri, archive_directory=None):
             if exc is None:
                 exc = e
     if exc is not None:
-        print 'TextFromURI: open %s caught: %s' % (uri, exc)
+        _log.error('open %s', uri, exc_info=exc)
         raise exc
     try:
         # Protect this in case whatever stream is doesn't have an fp
@@ -669,7 +664,7 @@ def TextFromURI (uri, archive_directory=None):
         try:
             OpenOrCreate(dest_file).write(xmls)
         except OSError, e:
-            print 'WARNING: Unable to save %s in %s: %s' % (uri, dest_file, e)
+            _log.warning('Unable to save %s in %s: %s', uri, dest_file, e)
     return xmls
 
 def OpenOrCreate (file_name, tag=None, preserve_contents=False):
@@ -742,7 +737,6 @@ try:
     import uuid
     __HaveUUID = True
 except ImportError:
-    import time
     import random
 def _NewUUIDString ():
     """Obtain a UUID using the best available method.  On a version of
@@ -810,7 +804,7 @@ class UniqueIdentifier (object):
     def associateObject (self, obj):
         """Associate the given object witth this identifier.
 
-        This is a one-way associatoin: the object is not provided with
+        This is a one-way association: the object is not provided with
         a return path to this identifier instance."""
         self.__associatedObjects.add(obj)
     def associatedObjects (self):
@@ -850,9 +844,6 @@ class UniqueIdentifier (object):
     def __repr__ (self):
         return 'pyxb.utils.utility.UniqueIdentifier(%s)' % (repr(self.uid()),)
 
-import datetime
-import calendar
-import time
 class UTCOffsetTimeZone (datetime.tzinfo):
     """A C{datetime.tzinfo} subclass that helps deal with UTC
     conversions in an ISO8601 world.
@@ -1010,10 +1001,8 @@ class PrivateTransient_mixin (pyxb.cscRoot):
                         cl2 = k[:-len(self.__Attribute)]
                         skipped.update([ '%s__%s' % (cl2, _n) for _n in v ])
             setattr(self.__class__, attr, skipped)
-            #print 'Defined skipped for %s: %s' % (self.__class__, skipped)
         for k in skipped:
             if state.get(k) is not None:
-                #print 'Stripping %s from instance %x of %s' % (k, id(self), type(self))
                 del state[k]
         # Uncomment the following to test whether undesirable types
         # are being pickled, generally by accidently leaving a
@@ -1045,9 +1034,12 @@ def GetMatchingFiles (path, pattern=None, default_path_wildcard=None, default_pa
     C{/opt/pyxb/bundles}, or non-recursively within
     C{/usr/local/pyxb/nsarchives}.
 
-    @param path: A colon separated list of directories in which the
-    search should be performed.  If a path entry ends with C{//}, any
-    directory beneath it is scanned as well, recursively.
+    @param path: A list of directories in which the search should be
+    performed.  The entries are separated by os.pathsep, which is a
+    colon on POSIX platforms and a semi-colon on Windows.  If a path
+    entry ends with C{//} regardless of platform, the suffix C{//} is
+    stripped and any directory beneath the path is scanned as well,
+    recursively.
 
     @keyword pattern: Optional regular expression object used to
     determine whether a given directory entry should be returned.  If
@@ -1071,12 +1063,12 @@ def GetMatchingFiles (path, pattern=None, default_path_wildcard=None, default_pa
     area.
     """
     matching_files = []
-    path_set = path.split(':')
+    path_set = path.split(os.pathsep)
     while 0 < len(path_set):
         path = path_set.pop(0)
         if default_path_wildcard == path:
             if default_path is not None:
-                path_set[0:0] = default_path.split(':')
+                path_set[0:0] = default_path.split(os.pathsep)
                 default_path = None
             continue
         recursive = False
@@ -1097,33 +1089,14 @@ def GetMatchingFiles (path, pattern=None, default_path_wildcard=None, default_pa
                     break
     return matching_files
     
-class _LocationBase (object):
-    """Wrap a location.
-
-    This is probably a string, but might be a uri object or the like.
-    Really we only have this as a separate object so as to avoid
-    creating hundreds of copies of the same string."""
-
-    __locationBase = None
-    def locationBase (self):
-        return self.__locationBase
-
-    def __init__ (self, location_base):
-        if isinstance(location_base, _LocationBase):
-            location_base = location_base.locationBase()
-        self.__locationBase = location_base
-
-    def __str__ (self):
-        return str(self.__locationBase)
-
 class Location (object):
     __locationBase = None
     __lineNumber = None
     __columnNumber = None
 
     def __init__ (self, location_base=None, line_number=None, column_number=None):
-        if not isinstance(location_base, _LocationBase):
-            location_base = _LocationBase(location_base)
+        if isinstance(location_base, str):
+            location_base = intern(location_base)
         self.__locationBase = location_base
         self.__lineNumber = line_number
         self.__columnNumber = column_number
@@ -1146,6 +1119,11 @@ class Location (object):
             return '<unknownLocation>'
         return '%s[%s:%s]' % (self.locationBase, self.lineNumber, self.columnNumber)
 
+    def __repr__ (self):
+        t = type(self)
+        ctor = '%s.%s' % (t.__module__, t.__name__)
+        return '%s(%r, %r, %r)' % (ctor, self.__locationBase, self.__lineNumber, self.__columnNumber)
+
 class Locatable_mixin (pyxb.cscRoot):
     __location = None
 
