@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+import logging
+if __name__ == '__main__':
+    logging.basicConfig()
+_log = logging.getLogger(__name__)
 from pyxb.utils.domutils import BindingDOMSupport
 import unittest
 
