@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+import logging
+if __name__ == '__main__':
+    logging.basicConfig()
+_log = logging.getLogger(__name__)
 import pyxb
 import pyxb.binding.generate
 import pyxb.utils.domutils
@@ -5,8 +10,8 @@ from xml.dom import Node
 
 import pyxb.binding.basis
 import os.path
-schema_path = '%s/../schemas/test-collision.xsd' % (os.path.dirname(__file__),)
-code = pyxb.binding.generate.GeneratePython(schema_location=schema_path, binding_style=pyxb.binding.basis.BINDING_STYLE_PROPERTY)
+schema_path = os.path.abspath(os.path.join(os.path.dirname(__file__), '../schemas/test-collision.xsd'))
+code = pyxb.binding.generate.GeneratePython(schema_location=schema_path)
 #file('code.py', 'w').write(code)
 
 rv = compile(code, 'test', 'exec')
@@ -18,14 +23,7 @@ import unittest
 
 class TestCollision (unittest.TestCase):
 
-    def setUp (self):
-        pyxb.binding.basis.ConfigureBindingStyle(pyxb.binding.basis.BINDING_STYLE_PROPERTY)
-
-    def tearDown (self):
-        pyxb.binding.basis.ConfigureBindingStyle(pyxb.binding.basis.DEFAULT_BINDING_STYLE)
-
     def testBasic (self):
-        self.assertEqual(pyxb.binding.basis.CURRENT_BINDING_STYLE, pyxb.binding.basis.BINDING_STYLE_PROPERTY)
         instance = color(color_.red, color_=color_.green)
         self.assertEqual('<color color="green"><color>red</color></color>', instance.toxml("utf-8", root_only=True))
         instance.color = color_.blue
