@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+import logging
+if __name__ == '__main__':
+    logging.basicConfig()
+_log = logging.getLogger(__name__)
 import pyxb.binding.generate
 import pyxb.utils.domutils
 from xml.dom import Node
