@@ -1,6 +1,12 @@
+# -*- coding: utf-8 -*-
+import logging
+if __name__ == '__main__':
+    logging.basicConfig()
+_log = logging.getLogger(__name__)
 import unittest
 from pyxb.utils.utility import *
 from pyxb.utils.utility import _DeconflictSymbols_mixin
+import sys
 
 class DST_base (_DeconflictSymbols_mixin):
     _ReservedSymbols = set([ 'one', 'two' ])
@@ -407,7 +413,9 @@ class TestOpenOrCreate_ExistingTagMismatch (unittest.TestCase, _TestOpenOrCreate
         tag = 'MyTagXX'
         text = 'This file has the tag NotMyTag in it'
         file(filename, 'w').write(text)
-        self.assertTrue(0 < file(filename, 'a').tell())
+        # Verify that opening for append will be positioned after the text.
+        if 'win32' != sys.platform:
+            self.assertTrue(0 < file(filename, 'a').tell())
         self.assertEqual(text, file(filename).read())
         self.assertRaises(OSError, OpenOrCreate, filename, tag=tag)
 
@@ -557,7 +565,9 @@ class TestGetMatchingFiles (unittest.TestCase):
                   'd1/d12/d121/f121a.wxs' ]
         [ file(os.path.join(self.__directory, _f), 'w') for _f in files ]
 
-        os.symlink(os.path.join(self.__directory, 'd2'), os.path.join(self.__directory, 'd1', 'd11', 'l2'))
+        self.__haveSymlink = hasattr(os, 'symlink')
+        if self.__haveSymlink:
+            os.symlink(os.path.join(self.__directory, 'd2'), os.path.join(self.__directory, 'd1', 'd11', 'l2'))
 
     def tearDown (self):
         #print 'teardown %s' % (self.__directory,)
@@ -578,22 +588,26 @@ class TestGetMatchingFiles (unittest.TestCase):
                 out_args.append(a)
             else:
                 out_args.append(os.path.join(self.__directory, a))
-        return ':'.join(out_args)
+        return os.pathsep.join(out_args)
 
     def _stripPath (self, files):
-        return [ _f[len(self.__directory)+1:] for _f in files ]
+        return [ _f[len(self.__directory)+1:].replace(os.sep, '/') for _f in files ]
 
     def testFormPath (self):
         # Make sure _formPath preserves trailing slashes
         saved_dir = self.__directory
         candidates = [ 'a', 'a/', 'a//', '+' ]
         try:
-            self.__directory = '/test'
+            self.__directory = os.path.join(os.sep, 'test')
             expanded = self._formPath(*candidates)
-            self.assertEqual('/test/a:/test/a/:/test/a//:+', expanded)
+            expected = os.pathsep.join([os.path.join(self.__directory, 'a'),
+                                        os.path.join(self.__directory, 'a', ''),
+                                        os.path.join(self.__directory, 'a//'),
+                                        '+'])
+            self.assertEqual(expected, expanded)
             candidates.pop()
             expanded = self._formPath(*candidates)
-            condensed = self._stripPath(expanded.split(':'))
+            condensed = self._stripPath(expanded.split(os.pathsep))
             self.assertEqual(candidates, condensed)
         finally:
             self.__directory = saved_dir
@@ -615,8 +629,9 @@ class TestGetMatchingFiles (unittest.TestCase):
         self.assertEqual(files, set(['d1/f1a.wxs', 'd1/f1b.wxs', 'd1/f1c', 'd2/f2a.wxs', 'd2/f2b']))
 
     def testLink (self):
-        files = set(self._stripPath(GetMatchingFiles(self._formPath(os.path.join('d1', 'd11', 'l2')))))
-        self.assertEqual(files, set(['d1/d11/l2/f2a.wxs', 'd1/d11/l2/f2b']))
+        if self.__haveSymlink:
+            files = set(self._stripPath(GetMatchingFiles(self._formPath(os.path.join('d1', 'd11', 'l2')))))
+            self.assertEqual(files, set(['d1/d11/l2/f2a.wxs', 'd1/d11/l2/f2b']))
 
     def testDefault (self):
         kw = { 'default_path' : self._formPath('d1'),
@@ -632,7 +647,7 @@ class TestGetMatchingFiles (unittest.TestCase):
         kw = { 'prefix_pattern' : '&',
                'prefix_substituend' : self.__directory }
         # Note: &/d1 => /d1 so it does not count
-        files = set(self._stripPath(GetMatchingFiles('&/d1:&d2', self.__NoExt_re, **kw)))
+        files = set(self._stripPath(GetMatchingFiles(os.pathsep.join([os.path.join('&', 'd1'), '&d2']), self.__NoExt_re, **kw)))
         self.assertEqual(files, set(['d2/f2b']))
 
     def testRecursive (self):
